[Libreoffice-commits] core.git: compilerplugins/clang editeng/source include/editeng include/oox include/sfx2 include/svtools include/svx include/xmloff oox/source sd/source sfx2/source svtools/source

2017-05-24 Thread Noel Grandin
 compilerplugins/clang/constantparam.bitmask.results  |   42 
 compilerplugins/clang/constantparam.booleans.results | 3040 
 compilerplugins/clang/constantparam.constructors.results |  832 
 compilerplugins/clang/constantparam.numbers.results  | 2804 
 compilerplugins/clang/constantparam.others.results   |292268 
+++
 compilerplugins/clang/constantparam.py   |   18 
 editeng/source/editeng/impedit3.cxx  |6 
 editeng/source/items/svxfont.cxx |   11 
 include/editeng/svxfont.hxx  |2 
 include/oox/vml/vmlshapecontainer.hxx|8 
 include/sfx2/objsh.hxx   |2 
 include/svtools/imap.hxx |8 
 include/svtools/imapcirc.hxx |4 
 include/svtools/imappoly.hxx |4 
 include/svtools/imaprect.hxx |4 
 include/svx/svdotext.hxx |4 
 include/xmloff/numehelp.hxx  |5 
 oox/source/drawingml/shape.cxx   |2 
 oox/source/vml/vmlshape.cxx  |6 
 oox/source/vml/vmlshapecontainer.cxx |   18 
 sd/source/ui/func/fuinsfil.cxx   |2 
 sfx2/source/doc/objmisc.cxx  |   22 
 sfx2/source/doc/objstor.cxx  |2 
 svtools/source/misc/imap.cxx |   16 
 svtools/source/misc/imap2.cxx|   56 
 svx/source/svdraw/svdotxln.cxx   |5 
 vcl/inc/opengl/texture.hxx   |6 
 vcl/inc/unx/fontmanager.hxx  |2 
 vcl/opengl/RenderList.cxx|2 
 vcl/opengl/texture.cxx   |8 
 vcl/unx/generic/fontmanager/fontconfig.cxx   |6 
 vcl/unx/generic/fontmanager/fontmanager.cxx  |6 
 xmloff/source/style/numehelp.cxx |2 
 33 files changed, 299097 insertions(+), 126 deletions(-)

New commits:
commit 4a340e36e8d3713806719351f455711c1254a178
Author: Noel Grandin 
Date:   Wed May 24 14:29:48 2017 +0200

loplugin:constantparam

add the results files so I can just see the diff in future

Change-Id: Ia20a1aa6418be95ed620719cde340c00b7b053e1
Reviewed-on: https://gerrit.libreoffice.org/37988
Tested-by: Jenkins 
Reviewed-by: Noel Grandin 

diff --git a/compilerplugins/clang/constantparam.bitmask.results 
b/compilerplugins/clang/constantparam.bitmask.results
new file mode 100644
index ..975005fc2817
--- /dev/null
+++ b/compilerplugins/clang/constantparam.bitmask.results
@@ -0,0 +1,42 @@
+codemaker/source/javamaker/classfile.hxx:153
+void codemaker::javamaker::ClassFile::ClassFile(enum 
codemaker::javamaker::ClassFile::AccessFlags,const class rtl::OString &,const 
class rtl::OString &,const class rtl::OString &)
+enum codemaker::javamaker::ClassFile::AccessFlags accessFlags setBits=0x1
+codemaker/source/javamaker/classfile.hxx:168
+void codemaker::javamaker::ClassFile::addField(enum 
codemaker::javamaker::ClassFile::AccessFlags,const class rtl::OString &,const 
class rtl::OString &,unsigned short,const class rtl::OString &)
+enum codemaker::javamaker::ClassFile::AccessFlags accessFlags setBits=0x1
+cui/source/options/webconninfo.hxx:35
+void svx::PasswordTable::InsertHeaderItem(unsigned short,const class 
rtl::OUString &,enum HeaderBarItemBits)
+enum HeaderBarItemBits nBits setBits=0x211 clearBits=0x1ee
+dbaccess/source/filter/xml/xmlExport.hxx:172
+void dbaxml::ODBExport::ODBExport(const class 
com::sun::star::uno::Reference 
&,const class rtl::OUString &,enum SvXMLExportFlags)
+enum SvXMLExportFlags nExportFlag setBits=0x400 clearBits=0x200
+include/framework/framelistanalyzer.hxx:181
+void framework::FrameListAnalyzer::FrameListAnalyzer(const class 
com::sun::star::uno::Reference 
&,const class com::sun::star::uno::Reference &,enum FrameAnalyzerFlags)
+enum FrameAnalyzerFlags eDetectMode setBits=0x4
+include/svl/itemset.hxx:134
+void SfxItemSet::PutExtended(const class SfxItemSet &,enum 
SfxItemState,enum SfxItemState)
+enum SfxItemState eDefaultAs setBits=0x20 clearBits=0xf
+include/svtools/brwbox.hxx:441
+void BrowseBox::InsertDataColumn(unsigned short,const class rtl::OUString 
&,long,enum HeaderBarItemBits,unsigned short)
+enum HeaderBarItemBits nBits setBits=0x410 clearBits=0x3ac
+include/svtools/wizardmachine.hxx:173
+void svt::OWizardMachine::OWizardMachine(class vcl::Window *,enum 
WizardButtonFlags)
+enum WizardButtonFlags _nButtonFlags setBits=0xf
+include/vcl/bitmapex.hxx:82
+void BitmapEx::SetSizePixel(const class Size &,enum BmpScaleFlag)
+enum BmpScale

[Libreoffice-commits] core.git: svl/source

2017-05-24 Thread Kohei Yoshida
 svl/source/misc/sharedstring.cxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 50fc62ce76bc51f18b16eae937761d0a8872df3e
Author: Kohei Yoshida 
Date:   Tue May 23 20:52:02 2017 -0400

tdf#107945: Perhaps this will make this method thread-safe...

Assuming that rtl_uString_new() is thread-safe, and static variable
initialization is technically thread-safe, hopefully we can declare
this static method thread-safe now.

Change-Id: Ibc3685a576c2a6692bdf2beff79592290b42cc8a
Reviewed-on: https://gerrit.libreoffice.org/38011
Tested-by: Jenkins 
Reviewed-by: Kohei Yoshida 

diff --git a/svl/source/misc/sharedstring.cxx b/svl/source/misc/sharedstring.cxx
index 9235783ce774..28f6473d0377 100644
--- a/svl/source/misc/sharedstring.cxx
+++ b/svl/source/misc/sharedstring.cxx
@@ -15,7 +15,7 @@ SharedString SharedString::getEmptyString()
 {
 // unicode string array for empty string is globally shared in OUString.
 // Let's take advantage of that.
-rtl_uString* pData = nullptr;
+static rtl_uString* pData = nullptr;
 rtl_uString_new(&pData);
 return SharedString(pData, pData);
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: Branch 'libreoffice-5-4' - include/svx svx/source sw/source

2017-05-24 Thread Maxim Monastirsky
 include/svx/nbdtmg.hxx |5 +++--
 svx/source/sidebar/nbdtmg.cxx  |   19 ++-
 sw/source/uibase/shells/txtnum.cxx |   15 ---
 3 files changed, 25 insertions(+), 14 deletions(-)

New commits:
commit fcee8ad5a1f326f3b6a63ca9e3e367c9e2c42515
Author: Maxim Monastirsky 
Date:   Tue May 23 20:49:48 2017 +0300

tdf#107008 Pass char style names to NBOTypeMgrBase

Change-Id: I26db31b8f9db968aa33b92a4abe917ac20cd5844
Reviewed-on: https://gerrit.libreoffice.org/37963
Tested-by: Jenkins 
Reviewed-by: Maxim Monastirsky 
(cherry picked from commit 687c3b49976ef0eb079853f7bffd63d25bff05c7)
Reviewed-on: https://gerrit.libreoffice.org/37989

diff --git a/include/svx/nbdtmg.hxx b/include/svx/nbdtmg.hxx
index aeb4ae6651fb..004fecd7b777 100644
--- a/include/svx/nbdtmg.hxx
+++ b/include/svx/nbdtmg.hxx
@@ -122,6 +122,7 @@ class SVX_DLLPUBLIC NBOTypeMgrBase
 const SfxItemSet*   pSet;
 MapUnit eCoreUnit;
 // store the attributes passed from pSet
+OUStringaBulletCharFmtName;
 OUStringaNumCharFmtName;
 NBOTypeMgrBase(const NBOTypeMgrBase&) = delete;
 
@@ -129,7 +130,6 @@ class SVX_DLLPUBLIC NBOTypeMgrBase
 NBOTypeMgrBase()
 : pSet(nullptr)
 , eCoreUnit(MapUnit::MapTwip)
-, aNumCharFmtName(OUString())
 , bIsLoading(false)
 {}
 virtual ~NBOTypeMgrBase() {}
@@ -143,7 +143,8 @@ class SVX_DLLPUBLIC NBOTypeMgrBase
 // store the attributes passed from pSet
 void SetItems(const SfxItemSet* pArg);
 protected:
-const OUString& GetBulCharFmtName() { return aNumCharFmtName;}
+const OUString& GetBulletCharFmtName() { return aBulletCharFmtName;}
+const OUString& GetNumCharFmtName() { return aNumCharFmtName;}
 MapUnit GetMapUnit() { return eCoreUnit;}
 protected:
 boolbIsLoading;
diff --git a/svx/source/sidebar/nbdtmg.cxx b/svx/source/sidebar/nbdtmg.cxx
index a07634897d1f..40ac42fccdd8 100644
--- a/svx/source/sidebar/nbdtmg.cxx
+++ b/svx/source/sidebar/nbdtmg.cxx
@@ -147,12 +147,14 @@ void NBOTypeMgrBase::SetItems(const SfxItemSet* pArg) {
 if ( pSet )
 {
 SfxAllItemSet aSet(*pSet);
+
 const SfxStringItem* pBulletCharFmt = 
aSet.GetItem(SID_BULLET_CHAR_FMT, false);
+if (pBulletCharFmt)
+aBulletCharFmtName = pBulletCharFmt->GetValue();
 
-if ( pBulletCharFmt )
-{
-aNumCharFmtName =  pBulletCharFmt->GetValue();
-}
+const SfxStringItem* pNumCharFmt = 
aSet.GetItem(SID_NUM_CHAR_FMT, false);
+if (pNumCharFmt)
+aNumCharFmtName = pNumCharFmt->GetValue();
 
 const SfxPoolItem* pItem;
 SfxItemState eState = pSet->GetItemState(SID_ATTR_NUMBERING_RULE, 
false, &pItem);
@@ -380,7 +382,7 @@ void BulletsTypeMgr::ApplyNumRule(SvxNumRule& aNum, 
sal_uInt16 nIndex, sal_uInt1
 const vcl::Font& rActBulletFont = pActualBullets[nIndex]->aFont;
 
 sal_uInt16 nMask = 1;
-OUString sBulletCharFormatName = GetBulCharFmtName();
+OUString sBulletCharFormatName = GetBulletCharFmtName();
 for(sal_uInt16 i = 0; i < aNum.GetLevelCount(); i++)
 {
 if(mLevel & nMask)
@@ -557,7 +559,7 @@ void NumberingTypeMgr::ApplyNumRule(SvxNumRule& aNum, 
sal_uInt16 nIndex, sal_uIn
 SvxNumType eNewType = _pSet->pNumSetting->nNumberType;
 
 sal_uInt16 nMask = 1;
-OUString sNumCharFmtName = GetBulCharFmtName();
+OUString sNumCharFmtName = GetNumCharFmtName();
 for(sal_uInt16 i = 0; i < aNum.GetLevelCount(); i++)
 {
 if(mLevel & nMask)
@@ -824,7 +826,6 @@ void OutlineTypeMgr::ApplyNumRule(SvxNumRule& aNum, 
sal_uInt16 nIndex, sal_uInt1
 NumSettingsArr_Impl *pNumSettingsArr=pItemArr->pNumSettingsArr;
 
 NumSettings_Impl* pLevelSettings = nullptr;
-OUString sBulletCharFormatName = GetBulCharFmtName();
 for(sal_uInt16 i = 0; i < aNum.GetLevelCount(); i++)
 {
 if(pNumSettingsArr->size() > i)
@@ -886,7 +887,7 @@ void OutlineTypeMgr::ApplyNumRule(SvxNumRule& aNum, 
sal_uInt16 nIndex, sal_uInt1
 }
 
 aFmt.SetBulletChar(cChar);
-aFmt.SetCharFormatName( sBulletCharFormatName );
+aFmt.SetCharFormatName( GetBulletCharFmtName() );
 if (isResetSize) aFmt.SetBulletRelSize(45);
 }else if ((aFmt.GetNumberingType()&(~LINK_TOKEN)) == SVX_NUM_BITMAP ) {
 if (pLevelSettings->pBrushItem) {
@@ -905,7 +906,7 @@ void OutlineTypeMgr::ApplyNumRule(SvxNumRule& aNum, 
sal_uInt16 nIndex, sal_uInt1
 } else
 {
 aFmt.SetIncludeUpperLevels(sal::static_int_cast< sal_uInt8 >(0 != 
nUpperLevelOrChar ? aNum.GetLevelCount() : 0));
-aFmt.SetCharFormatName(sBulletCharFormatName);
+aFmt.SetCharFormatName(GetNumCharFmtName());
 if (isResetSize) aFmt.SetBulletRelSize(100);
 }
 if(pN

[Libreoffice-commits] core.git: Branch 'distro/collabora/cp-5.3' - sc/inc sc/Library_sc.mk sc/source

2017-05-24 Thread Kohei Yoshida
 sc/Library_sc.mk   |1 
 sc/inc/cellvalue.hxx   |   33 ++-
 sc/inc/column.hxx  |5 +++
 sc/inc/columniterator.hxx  |   29 
 sc/inc/document.hxx|   13 +
 sc/inc/formulacell.hxx |   10 +++
 sc/inc/mtvcellfunc.hxx |   12 
 sc/inc/table.hxx   |5 +++
 sc/source/core/data/cellvalue.cxx  |   46 +
 sc/source/core/data/column4.cxx|   26 ++
 sc/source/core/data/columniterator.cxx |   37 ++
 sc/source/core/data/document10.cxx |   23 
 sc/source/core/data/dpcache.cxx|   46 +
 sc/source/core/data/formulacell.cxx|   14 --
 sc/source/core/data/mtvcellfunc.cxx|   31 ++
 sc/source/core/data/table7.cxx |   18 
 16 files changed, 324 insertions(+), 25 deletions(-)

New commits:
commit be5429112c8ed1a4ecd8b032aa85f14e3625e7e9
Author: Kohei Yoshida 
Date:   Mon May 22 21:08:56 2017 -0400

tdf#107945: properly iterate over mtv during pivot cache loading.

This reduces the total time required for populating the pivot cache
by ~60%.

Reviewed-on: https://gerrit.libreoffice.org/37971
Tested-by: Jenkins 
Reviewed-by: Kohei Yoshida 
(cherry picked from commit d4cd8677889ec3807c194ef5b462f8e031807e5b)

 Conflicts:
sc/inc/document.hxx
sc/source/core/data/formulacell.cxx

Change-Id: I6a8511959c20231a8a5dbd0b0a9a3d0930a1fa0c

diff --git a/sc/Library_sc.mk b/sc/Library_sc.mk
index 3714c966a62e..329fe87840b8 100644
--- a/sc/Library_sc.mk
+++ b/sc/Library_sc.mk
@@ -167,6 +167,7 @@ $(eval $(call gb_Library_add_exception_objects,sc,\
 sc/source/core/data/markarr \
 sc/source/core/data/markdata \
 sc/source/core/data/markmulti \
+sc/source/core/data/mtvcellfunc \
 sc/source/core/data/mtvelements \
 sc/source/core/data/olinetab \
 sc/source/core/data/pagepar \
diff --git a/sc/inc/cellvalue.hxx b/sc/inc/cellvalue.hxx
index 4ebd29889fee..430212245870 100644
--- a/sc/inc/cellvalue.hxx
+++ b/sc/inc/cellvalue.hxx
@@ -132,19 +132,38 @@ struct SC_DLLPUBLIC ScRefCellValue
 
 bool hasNumeric() const;
 
+bool hasError() const;
+
 double getValue();
 
-/** Retrieve string value.
+/**
+ * Retrieve a numeric value without modifying the states of any objects in
+ * the referenced document store.
+ */
+double getRawValue() const;
 
-@param  pDoc
-Needed to resolve EditCells' field contents, obtain a
-ScFieldEditEngine from that document. May be NULL if there is
-no ScDocument in the calling context but then the document
-specific fields can not be resolved. See
-ScEditUtil::GetString().
+/**
+ *  Retrieve string value.
+ *
+ *  Note that this method is NOT thread-safe.
+ *
+ *  @param  pDoc
+ *  Needed to resolve EditCells' field contents, obtain a
+ *  ScFieldEditEngine from that document. May be NULL if there is
+ *  no ScDocument in the calling context but then the document
+ *  specific fields can not be resolved. See
+ *  ScEditUtil::GetString().
  */
 OUString getString( const ScDocument* pDoc );
 
+/**
+ * Retrieve a string value without modifying the states of any objects in
+ * the referenced document store.
+ *
+ * This method is thread-safe.
+ */
+OUString getRawString( const ScDocument* pDoc ) const;
+
 bool isEmpty() const;
 
 bool hasEmptyValue();
diff --git a/sc/inc/column.hxx b/sc/inc/column.hxx
index 143610767117..f0a30d82e568 100644
--- a/sc/inc/column.hxx
+++ b/sc/inc/column.hxx
@@ -67,6 +67,7 @@ class CompileFormulaContext;
 struct SetFormulaDirtyContext;
 class RefMovedHint;
 enum class MatrixEdge;
+class ColumnIterator;
 
 }
 
@@ -666,6 +667,10 @@ public:
 void SwapNonEmpty(
 sc::TableValues& rValues, sc::StartListeningContext& rStartCxt, 
sc::EndListeningContext& rEndCxt );
 
+std::unique_ptr GetColumnIterator( SCROW nRow1, SCROW 
nRow2 ) const;
+
+void EnsureFormulaCellResults( SCROW nRow1, SCROW nRow2 );
+
 #if DUMP_COLUMN_STORAGE
 void DumpColumnStorage() const;
 #endif
diff --git a/sc/inc/columniterator.hxx b/sc/inc/columniterator.hxx
index 4e8c951be750..e4906204c9b4 100644
--- a/sc/inc/columniterator.hxx
+++ b/sc/inc/columniterator.hxx
@@ -50,6 +50,35 @@ private:
 void checkEndRow();
 };
 
+namespace sc {
+
+/**
+ * This iterator lets you iterate over cells over specified range in a
+ * single column.  It does not modify the state of the cells, and therefore
+ * is thread safe.
+ */
+class ColumnIterator
+{
+CellStoreType::const_position_type maPo

[Libreoffice-commits] online.git: 2 commits - common/Util.cpp common/Util.hpp .gitignore Makefile.am tools/Config.cpp wsd/FileServer.cpp

2017-05-24 Thread Pranav Kant
 .gitignore |1 
 Makefile.am|4 
 common/Util.cpp|   21 
 common/Util.hpp|2 
 tools/Config.cpp   |  229 +
 wsd/FileServer.cpp |   46 +-
 6 files changed, 298 insertions(+), 5 deletions(-)

New commits:
commit 7a4bc5b95a9722a23048a7cd076bd1c4a954a9e9
Author: Pranav Kant 
Date:   Thu May 25 01:07:20 2017 +0530

admin-console: Check the password against hashed value in config

The new password hash property is called secure_password in the config
file. `loolconfig` tool should be used to set the password hash in
appropriate format with desired salt length, password length, number of
iterations in PBKDF2.

To be backward compatible, plain-text password for admin-console in
config file is still accepted in case secure_password property is
missing from the config file.

Change-Id: If22dac62856e368555c0242c4aa6f8061fba

diff --git a/common/Util.cpp b/common/Util.cpp
index 803ebfb0..66d917d8 100644
--- a/common/Util.cpp
+++ b/common/Util.cpp
@@ -111,6 +111,27 @@ namespace Util
 }
 }
 
+bool dataFromHexString(const std::string& hexString, std::vector& data)
+{
+if (hexString.length() % 2 != 0)
+{
+return false;
+}
+
+data.clear();
+std::stringstream stream;
+unsigned value;
+for (unsigned offset = 0; offset < hexString.size(); offset += 2)
+{
+stream.clear();
+stream << std::hex << hexString.substr(offset, 2);
+stream >> value;
+data.push_back(static_cast(value));
+}
+
+return true;
+}
+
 std::string encodeId(const unsigned number, const int padding)
 {
 std::ostringstream oss;
diff --git a/common/Util.hpp b/common/Util.hpp
index d2803a42..8c720774 100644
--- a/common/Util.hpp
+++ b/common/Util.hpp
@@ -42,6 +42,8 @@ namespace Util
 std::string getFilename(const size_t length);
 }
 
+/// Hex to unsigned char
+bool dataFromHexString(const std::string& hexString, std::vector& data);
 /// Encode an integral ID into a string, with padding support.
 std::string encodeId(const unsigned number, const int padding = 5);
 /// Decode an integral ID from a string.
diff --git a/tools/Config.cpp b/tools/Config.cpp
index 60be997c..1692453d 100644
--- a/tools/Config.cpp
+++ b/tools/Config.cpp
@@ -216,6 +216,7 @@ int Config::main(const std::vector& args)
 
 std::cout << "Saving configuration to : " << ConfigFile << " ..." 
<< std::endl;
 _loolConfig.save(ConfigFile);
+std::cout << "Saved" << std::endl;
 }
 }
 
diff --git a/wsd/FileServer.cpp b/wsd/FileServer.cpp
index 99606959..18a82f5c 100644
--- a/wsd/FileServer.cpp
+++ b/wsd/FileServer.cpp
@@ -9,6 +9,7 @@
 
 #include "config.h"
 
+#include 
 #include 
 #include 
 #include 
@@ -16,6 +17,8 @@
 #include 
 #include 
 
+#include 
+
 #include 
 #include 
 #include 
@@ -37,6 +40,7 @@
 #include "Auth.hpp"
 #include "Common.hpp"
 #include "FileServer.hpp"
+#include "Protocol.hpp"
 #include "LOOLWSD.hpp"
 #include "Log.hpp"
 
@@ -77,18 +81,52 @@ bool FileServerRequestHandler::isAdminLoggedIn(const 
HTTPRequest& request,
 LOG_INF("No existing JWT cookie found");
 }
 
+HTTPBasicCredentials credentials(request);
+std::string userProvidedPwd = credentials.getPassword();
+
 // If no cookie found, or is invalid, let admin re-login
-const auto user = config.getString("admin_console.username", "");
-const auto pass = config.getString("admin_console.password", "");
+const std::string user = config.getString("admin_console.username", "");
+std::string pass = config.getString("admin_console.password", "");
+if (config.has("admin_console.secure_password"))
+{
+pass = config.getString("admin_console.secure_password");
+// Extract the salt from the config
+std::vector saltData;
+std::vector tokens = LOOLProtocol::tokenize(pass, '.');
+if (tokens.size() != 5 ||
+tokens[0] != "pbkdf2" ||
+tokens[1] != "sha512" ||
+!Util::dataFromHexString(tokens[3], saltData))
+{
+LOG_ERR("Incorrect format detected for secure_password in config 
file."
+<< "Denying access until correctly set."
+<< "Use loolconfig to configure admin password.");
+return false;
+}
+
+unsigned char userProvidedPwdHash[tokens[4].size() / 2];
+PKCS5_PBKDF2_HMAC(userProvidedPwd.c_str(), -1,
+  saltData.data(), saltData.size(),
+  std::stoi(tokens[2]),
+  EVP_sha512(),
+  sizeof userProvidedPwdHash, userProvidedPwdHash);
+
+std::stringstream stream;
+for (unsigned j = 0; j < sizeof userProvidedPwdHash; ++j)
+

[Libreoffice-commits] core.git: sw/inc sw/source

2017-05-24 Thread Jochen Nitschke
 sw/inc/fchrfmt.hxx |6 +-
 sw/source/core/doc/docnew.cxx  |   12 
 sw/source/core/para/paratr.cxx |1 +
 sw/source/core/unocore/SwXTextDefaults.cxx |3 +++
 sw/source/core/unocore/unoobj.cxx  |4 +---
 sw/source/core/unocore/unostyle.cxx|5 -
 6 files changed, 14 insertions(+), 17 deletions(-)

New commits:
commit 6d51bb3d54ac52e4870bd00a21fce3a3b1c5010b
Author: Jochen Nitschke 
Date:   Wed May 10 22:56:35 2017 +0200

tdf#106424 fix crash in SfxItemPool::Put

This fix reverts commit 304d3856c138fb54ff536f41be3eff26ab4d6315
Date:   Wed Oct 16 07:55:09 2002 +
#103124# possible unremoved SwFmt object fixed

and commit fab98924e01f211c1d1fc5823c0867019b590c60
Date:   Wed Oct 16 10:18:26 2002 +
#103152# possible unremoved SwFmt object fixed

as they are causing crashes:
http://crashreport.libreoffice.org/stats/signature
/SfxItemPool::Put(SfxPoolItem%20const%20&,unsigned%20short)

The comments suggest there was/is a use-after-free when
SwFormatCharFormat is changed with API. This happens in unoobj.cxx
and unostyle.cxx by SwFormatDrop::SetCharFormat().

With following changes:
commit bf2ae97a223df987d6b9bc649afe311b5421f61e
INTEGRATION: CWS os7 (1.64.4.3.34); FILE MERGED
2003/03/25 14:23:43 os 1.64.4.3.34.1: #104245# table mode added
to the SwXTextCursor::SetPropertyValue attribute list; 'Standard'
character format not allowed as drop cap char style
and commit 9625366d0b2fd36a57c6283a4a80c47b80d57707
INTEGRATION: CWS os8 (1.64.4.3.48); FILE MERGED
2003/04/09 09:11:53 os 1.64.4.3.48.3: #104245# Default not
allowed as DropCapCharStyleName, too

in unoobj.cxx, setting the documents' default SwFormatCharFormat is
rejected by throwing an exception. Likely to fix the same issue as
the first 2 commits.
So we do the same in unostyle.cxx now too.

Add an assert in SwFormatCharFormat::SetCharFormat and
SwFormatDrop::SetCharFormat, to uncover other changes to the default
SwFormatCharFormat or SwFormatDrop.
Such an case could happen in SwXTextDefaults::setPropertyValue
where we bail out now.

Change-Id: Iac59dffbd6285dd28d1000a8eacda8ffd3bdc962
Reviewed-on: https://gerrit.libreoffice.org/37499
Tested-by: Jenkins 
Reviewed-by: Michael Stahl 

diff --git a/sw/inc/fchrfmt.hxx b/sw/inc/fchrfmt.hxx
index 2d6c77f20d7d..90314b18d437 100644
--- a/sw/inc/fchrfmt.hxx
+++ b/sw/inc/fchrfmt.hxx
@@ -62,7 +62,11 @@ public:
 
 virtual boolGetInfo( SfxPoolItem& rInfo ) const override;
 
-void SetCharFormat( SwFormat* pFormat ) { pFormat->Add(this); }
+void SetCharFormat( SwFormat* pFormat )
+{
+assert(!pFormat->IsDefault()); // expose cases that lead to 
use-after-free
+pFormat->Add(this);
+}
 SwCharFormat* GetCharFormat() const { return 
const_cast(static_cast(GetRegisteredIn())); 
}
 };
 #endif
diff --git a/sw/source/core/doc/docnew.cxx b/sw/source/core/doc/docnew.cxx
index cb2a35160691..3d7b813fe964 100644
--- a/sw/source/core/doc/docnew.cxx
+++ b/sw/source/core/doc/docnew.cxx
@@ -41,8 +41,6 @@
 #include 
 #include 
 #include 
-#include 
-#include 
 #include 
 #include 
 #include 
@@ -384,16 +382,6 @@ SwDoc::~SwDoc()
 delete mpGrammarContact;
 mpGrammarContact = nullptr;
 
-//!! needs to be done to destroy a possible SwFormatDrop format that may
-//!! be connected to a char format which may not otherwise be removed
-//!! and thus would leave a unremoved SwFormat object. (TL)
-//!! (this is case is not possible via UI but via API...)
-SwFormatDrop aDrop;
-SetDefault(aDrop);
-//!! same for SwFormatCharFormat
-SwFormatCharFormat aCharFormat(nullptr);
-SetDefault(aCharFormat);
-
 getIDocumentTimerAccess().StopIdling();   // stop idle timer
 
 delete mpURLStateChgd;
diff --git a/sw/source/core/para/paratr.cxx b/sw/source/core/para/paratr.cxx
index a47786c373a2..aa76115b6528 100644
--- a/sw/source/core/para/paratr.cxx
+++ b/sw/source/core/para/paratr.cxx
@@ -64,6 +64,7 @@ SwFormatDrop::~SwFormatDrop()
 
 void SwFormatDrop::SetCharFormat( SwCharFormat *pNew )
 {
+assert(!pNew->IsDefault()); // expose cases that lead to use-after-free
 // Rewire
 if ( GetRegisteredIn() )
 GetRegisteredInNonConst()->Remove( this );
diff --git a/sw/source/core/unocore/SwXTextDefaults.cxx 
b/sw/source/core/unocore/SwXTextDefaults.cxx
index fd3c90d5d1d6..17b62c0afd98 100644
--- a/sw/source/core/unocore/SwXTextDefaults.cxx
+++ b/sw/source/core/unocore/SwXTextDefaults.cxx
@@ -92,6 +92,9 @@ void SAL_CALL SwXTextDefaults::setPropertyValue( const 
OUString& rPropertyName,
 if(pStyle)
 {
 rtl::Reference< SwDocStyleSheet > xStyle( new SwDocStyleSheet( 
*pStyle ) );
+if (xStyle->GetCharFormat

[Libreoffice-commits] online.git: loleaflet/src

2017-05-24 Thread Henry Castro
 loleaflet/src/control/Control.Menubar.js |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit c6b1d29578937c6c5b9edf120643f7331d19540e
Author: Henry Castro 
Date:   Wed May 24 15:25:36 2017 -0400

loleaflet: simplify disable about dialog

CreateMenu is a recursive function

Change-Id: Ied1b076c1ff04a1d471af2360aa8f9fbbe3289ff

diff --git a/loleaflet/src/control/Control.Menubar.js 
b/loleaflet/src/control/Control.Menubar.js
index 33d2e1e1..29c64bbb 100644
--- a/loleaflet/src/control/Control.Menubar.js
+++ b/loleaflet/src/control/Control.Menubar.js
@@ -541,8 +541,8 @@ L.Control.Menubar = L.Control.extend({
_createMenu: function(menu) {
var itemList = [];
for (var i in menu) {
-   if (menu[i].id === 'help' && disableAbout) {
-   menu[i].menu.pop();
+   if (menu[i].id === 'about' && disableAbout) {
+   continue;
}
 
if (map._permission === 'readonly' && menu[i].type === 
'menu') {
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: basic/qa basic/source

2017-05-24 Thread Grzegorz Araminowicz
 basic/qa/basic_coverage/test_date_literal.vb |   16 ++
 basic/source/comp/scanner.cxx|   67 +++
 2 files changed, 75 insertions(+), 8 deletions(-)

New commits:
commit f45463d8e2bb0771ec1837d159ff98108b0047cf
Author: Grzegorz Araminowicz 
Date:   Sat Apr 1 16:02:26 2017 +0200

tdf#93727 Support date literals in basic

* detect #...# in SbiScanner
* add vb test
* made date locale-independent

Change-Id: Ic269df2df8d3a7c5af7858c3655bb40a0b6033f0
Reviewed-on: https://gerrit.libreoffice.org/36002
Tested-by: Jenkins 
Reviewed-by: Eike Rathke 

diff --git a/basic/qa/basic_coverage/test_date_literal.vb 
b/basic/qa/basic_coverage/test_date_literal.vb
new file mode 100755
index ..a175368f3598
--- /dev/null
+++ b/basic/qa/basic_coverage/test_date_literal.vb
@@ -0,0 +1,16 @@
+'
+' This file is part of the LibreOffice project.
+'
+' This Source Code Form is subject to the terms of the Mozilla Public
+' License, v. 2.0. If a copy of the MPL was not distributed with this
+' file, You can obtain one at http://mozilla.org/MPL/2.0/.
+'
+
+
+Function doUnitTest as Integer
+  If #07/28/1977# = 28334 And #1977-07-28# = 28334 Then
+ doUnitTest = 1
+  Else
+ doUnitTest = 0
+  End If
+End Function
diff --git a/basic/source/comp/scanner.cxx b/basic/source/comp/scanner.cxx
index 4cd7928b3a02..65c8e3f6c4e6 100644
--- a/basic/source/comp/scanner.cxx
+++ b/basic/source/comp/scanner.cxx
@@ -21,6 +21,9 @@
 #include "scanner.hxx"
 #include "sbintern.hxx"
 
+#include 
+#include 
+#include 
 #include 
 
 SbiScanner::SbiScanner( const OUString& rBuf, StarBASIC* p ) : aBuf( rBuf )
@@ -245,13 +248,22 @@ bool SbiScanner::NextSym()
 
 if(nCol < aLine.getLength() && aLine[nCol] == '#')
 {
-++pLine;
-++nCol;
-//ignore compiler directives (# is first non-space character)
-if( nOldCol2 == 0 )
-bCompilerDirective = true;
-else
-bHash = true;
+const sal_Unicode* pLineTemp = pLine;
+do
+{
+pLineTemp++;
+} while (*pLineTemp && !BasicCharClass::isWhitespace(*pLineTemp) && 
*pLineTemp != '#');
+// leave it if it is a date literal - it will be handled later
+if (*pLineTemp != '#')
+{
+++pLine;
+++nCol;
+//ignore compiler directives (# is first non-space character)
+if (nOldCol2 == 0)
+bCompilerDirective = true;
+else
+bHash = true;
+}
 }
 
 // copy character if symbol
@@ -521,7 +533,7 @@ bool SbiScanner::NextSym()
 }
 aSym = aSymBuf.makeStringAndClear();
 if( cSep != ']' )
-eScanType = ( cSep == '#' ) ? SbxDATE : SbxSTRING;
+eScanType = SbxSTRING;
 break;
 }
 }
@@ -532,6 +544,45 @@ bool SbiScanner::NextSym()
 }
 }
 }
+
+// Date:
+else if( *pLine == '#' )
+{
+sal_Int32 n = nCol + 1;
+do
+{
+pLine++;
+nCol++;
+}
+while( *pLine && ( *pLine != '#' ) );
+if( *pLine == '#' )
+{
+pLine++; nCol++;
+aSym = aLine.copy( n, nCol - n - 1 );
+
+// parse date literal
+SvNumberFormatter 
aFormatter(comphelper::getProcessComponentContext(), LANGUAGE_ENGLISH_US);
+sal_uInt32 nIndex = 0;
+bool bSuccess = aFormatter.IsNumberFormat(aSym, nIndex, nVal);
+if( bSuccess )
+{
+short nType_ = aFormatter.GetType(nIndex);
+if( !(nType_ & css::util::NumberFormat::DATE) )
+bSuccess = false;
+}
+
+if (!bSuccess)
+GenError( ERRCODE_BASIC_CONVERSION );
+
+bNumber = true;
+eScanType = SbxDOUBLE;
+}
+else
+{
+aError = OUString('#');
+GenError( ERRCODE_BASIC_EXPECTED );
+}
+}
 // invalid characters:
 else if( *pLine >= 0x7F )
 {
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sd/qa

2017-05-24 Thread Caolán McNamara
 sd/qa/unit/dialogs-test.cxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit c6568ab9a6192675d72de58f72dd5d8e5c14db0a
Author: Caolán McNamara 
Date:   Wed May 24 17:36:50 2017 +0100

SdResId used just for its id

Change-Id: I37bc1e8f52c4968a26b12d5b9609dfe7b1f7827a

diff --git a/sd/qa/unit/dialogs-test.cxx b/sd/qa/unit/dialogs-test.cxx
index aa0837ecf3ce..b6d346fdd1d3 100644
--- a/sd/qa/unit/dialogs-test.cxx
+++ b/sd/qa/unit/dialogs-test.cxx
@@ -477,7 +477,7 @@ VclPtr 
SdDialogsTest::createDialogByID(sal_uInt32 nID)
 pRetval = 
getSdAbstractDialogFactory()->CreateSdPresLayoutTemplateDlg(
 getDocShell(),
 Application::GetDefDialogParent(),
-SdResId(TAB_PRES_LAYOUT_TEMPLATE),
+TAB_PRES_LAYOUT_TEMPLATE,
 *pStyleSheet,
 PO_TITLE,
 pStyleSheetPool);
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


Re: Failing tests on openSUSE

2017-05-24 Thread Rene Engelhard
Hi,

On Wed, May 24, 2017 at 02:15:52PM +0200, Markus Mohrhard wrote:
>All tests in master should pass a --with-fonts=no build. See e.g.
>[3]https://ci.libreoffice.org/job/lo_tb_random_config_linux/521/consoleFull

Apparently not, as this case showed. :)

You didn't happen to have dejavu installed somehow there?

(That patch already is in master and libreoffice-5-4 FTR)

Regards,

Rene
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: Branch 'libreoffice-5-4' - sc/source

2017-05-24 Thread Eike Rathke
 sc/source/core/tool/interpr1.cxx |  460 +++
 1 file changed, 232 insertions(+), 228 deletions(-)

New commits:
commit 16e2d84e5d0d06879c51add11380083ceb644d61
Author: Eike Rathke 
Date:   Wed May 24 12:23:27 2017 +0200

svRefList always needs to be in a loop to be eventually popped from stack

If it has more than one entries, rRefInList and rParam are incremented
(effectively annulating a nParam--) and only the last entry pops the
token from stack. This could had led to wrong references for other
(previous) parameters.

Backport of commits 69f9c57551120afbb7e2d877f8478148a0c545dc and
6df362b4b01a1f645009b45e1a7dd902f1de089b

Change-Id: I2d61522cdd7ce89ad6854d0f1e012f5df8ab6608
Reviewed-on: https://gerrit.libreoffice.org/37983
Reviewed-by: Eike Rathke 
Tested-by: Jenkins 

diff --git a/sc/source/core/tool/interpr1.cxx b/sc/source/core/tool/interpr1.cxx
index 0b3d515e3243..a9d4a36cd8c2 100644
--- a/sc/source/core/tool/interpr1.cxx
+++ b/sc/source/core/tool/interpr1.cxx
@@ -5313,8 +5313,6 @@ void ScInterpreter::IterateParametersIfs( 
sc::ParamIfsResult& rRes )
 size_t nRowSize = 0;
 size_t nColSize = 0;
 double fVal = 0.0;
-short nParam = 1;
-size_t nRefInList = 0;
 SCCOL nDimensionCols = 0;
 SCROW nDimensionRows = 0;
 
@@ -5396,8 +5394,8 @@ void ScInterpreter::IterateParametersIfs( 
sc::ParamIfsResult& rRes )
 return;   // and bail out, no need to evaluate other arguments
 
 // take range
-nParam = 1;
-nRefInList = 0;
+short nParam = nParamCount;
+size_t nRefInList = 0;
 SCCOL nCol1 = 0;
 SCROW nRow1 = 0;
 SCTAB nTab1 = 0;
@@ -5405,141 +5403,144 @@ void ScInterpreter::IterateParametersIfs( 
sc::ParamIfsResult& rRes )
 SCROW nRow2 = 0;
 SCTAB nTab2 = 0;
 ScMatrixRef pQueryMatrix;
-switch ( GetStackType() )
+while (nParam-- == nParamCount)
 {
-case svRefList :
-{
-ScRange aRange;
-PopDoubleRef( aRange, nParam, nRefInList);
-aRange.GetVars( nCol1, nRow1, nTab1, nCol2, nRow2, nTab2);
-}
+switch ( GetStackType() )
+{
+case svRefList :
+{
+ScRange aRange;
+PopDoubleRef( aRange, nParam, nRefInList);
+aRange.GetVars( nCol1, nRow1, nTab1, nCol2, nRow2, 
nTab2);
+}
 break;
-case svDoubleRef :
-PopDoubleRef( nCol1, nRow1, nTab1, nCol2, nRow2, nTab2 );
+case svDoubleRef :
+PopDoubleRef( nCol1, nRow1, nTab1, nCol2, nRow2, nTab2 );
 break;
-case svSingleRef :
-PopSingleRef( nCol1, nRow1, nTab1 );
-nCol2 = nCol1;
-nRow2 = nRow1;
-nTab2 = nTab1;
+case svSingleRef :
+PopSingleRef( nCol1, nRow1, nTab1 );
+nCol2 = nCol1;
+nRow2 = nRow1;
+nTab2 = nTab1;
 break;
-case svMatrix:
-case svExternalSingleRef:
-case svExternalDoubleRef:
-{
-pQueryMatrix = PopMatrix();
-if (!pQueryMatrix)
+case svMatrix:
+case svExternalSingleRef:
+case svExternalDoubleRef:
 {
-SetError( FormulaError::IllegalParameter);
-return;
+pQueryMatrix = PopMatrix();
+if (!pQueryMatrix)
+{
+SetError( FormulaError::IllegalParameter);
+return;
+}
+nCol1 = 0;
+nRow1 = 0;
+nTab1 = 0;
+SCSIZE nC, nR;
+pQueryMatrix->GetDimensions( nC, nR);
+nCol2 = static_cast(nC - 1);
+nRow2 = static_cast(nR - 1);
+nTab2 = 0;
 }
-nCol1 = 0;
-nRow1 = 0;
-nTab1 = 0;
-SCSIZE nC, nR;
-pQueryMatrix->GetDimensions( nC, nR);
-nCol2 = static_cast(nC - 1);
-nRow2 = static_cast(nR - 1);
-nTab2 = 0;
-}
 break;
-default:
-SetError( FormulaError::IllegalParameter);
+default:
+SetError( FormulaError::IllegalParameter);
+return;
+}
+if ( nTab1 != nTab2 )
+{
+   

[Libreoffice-commits] core.git: sdext/source

2017-05-24 Thread Michael Stahl
 sdext/source/presenter/PresenterScrollBar.cxx |1 
 sdext/source/presenter/PresenterScrollBar.hxx |3 
 sdext/source/presenter/PresenterTextView.cxx  |6 +
 sdext/source/presenter/PresenterTextView.hxx  |2 
 sdext/source/presenter/PresenterTimer.cxx |   96 +++---
 sdext/source/presenter/PresenterTimer.hxx |2 
 6 files changed, 101 insertions(+), 9 deletions(-)

New commits:
commit 15b033d1dd09cd1898a994a0f12e38ed5cf847cb
Author: Michael Stahl 
Date:   Wed May 24 16:14:56 2017 +0200

rhbz#1425304 sdext: join TimerScheduler thread before shutdown

Use a osl::Condition to interrupt the waiting thread, and join it.

Change-Id: I638a2495afd082446c39faf9362578bd0f758d04

diff --git a/sdext/source/presenter/PresenterScrollBar.cxx 
b/sdext/source/presenter/PresenterScrollBar.cxx
index 89ac7f52ce16..988b3d82d791 100644
--- a/sdext/source/presenter/PresenterScrollBar.cxx
+++ b/sdext/source/presenter/PresenterScrollBar.cxx
@@ -790,6 +790,7 @@ void PresenterScrollBar::MousePressRepeater::Start (const 
PresenterScrollBar::Ar
 // Schedule repeated executions.
 auto pThis(shared_from_this());
 mnMousePressRepeaterTaskId = PresenterTimer::ScheduleRepeatedTask (
+mpScrollBar->GetComponentContext(),
 [pThis] (TimeValue const& rTime) { return pThis->Callback(rTime); 
},
 5,
 25000);
diff --git a/sdext/source/presenter/PresenterScrollBar.hxx 
b/sdext/source/presenter/PresenterScrollBar.hxx
index 46a6704bc7f8..70c670e7fb34 100644
--- a/sdext/source/presenter/PresenterScrollBar.hxx
+++ b/sdext/source/presenter/PresenterScrollBar.hxx
@@ -58,6 +58,9 @@ public:
 
 virtual void SAL_CALL disposing() override;
 
+css::uno::Reference const&
+GetComponentContext() { return mxComponentContext; }
+
 void SetVisible (const bool bIsVisible);
 
 /** Set the bounding box of the scroll bar.
diff --git a/sdext/source/presenter/PresenterTextView.cxx 
b/sdext/source/presenter/PresenterTextView.cxx
index 3e4d174a21eb..ca48c6f15f4f 100644
--- a/sdext/source/presenter/PresenterTextView.cxx
+++ b/sdext/source/presenter/PresenterTextView.cxx
@@ -73,6 +73,7 @@ PresenterTextView::PresenterTextView (
   mpFont(),
   maParagraphs(),
   mpCaret(new PresenterTextCaret(
+  rxContext,
   [this] (sal_Int32 const nParagraphIndex, sal_Int32 const 
nCharacterIndex)
   { return this->GetCaretBounds(nParagraphIndex, nCharacterIndex); 
},
   rInvalidator)),
@@ -1068,9 +1069,11 @@ void PresenterTextParagraph::SetupCellArray (
 //= PresenterTextCaret 
 
 PresenterTextCaret::PresenterTextCaret (
+uno::Reference const& xContext,
 const ::std::function& rCharacterBoundsAccess,
 const ::std::function& rInvalidator)
-: mnParagraphIndex(-1),
+: m_xContext(xContext)
+, mnParagraphIndex(-1),
   mnCharacterIndex(-1),
   mnCaretBlinkTaskId(0),
   mbIsCaretVisible(false),
@@ -1091,6 +1094,7 @@ void PresenterTextCaret::ShowCaret()
 if (mnCaretBlinkTaskId == 0)
 {
 mnCaretBlinkTaskId = PresenterTimer::ScheduleRepeatedTask (
+m_xContext,
 [this] (TimeValue const&) { return this->InvertCaret(); },
 CaretBlinkInterval,
 CaretBlinkInterval);
diff --git a/sdext/source/presenter/PresenterTextView.hxx 
b/sdext/source/presenter/PresenterTextView.hxx
index cca8b4a89ad1..5c990c64e89e 100644
--- a/sdext/source/presenter/PresenterTextView.hxx
+++ b/sdext/source/presenter/PresenterTextView.hxx
@@ -41,6 +41,7 @@ class PresenterTextCaret
 {
 public:
 PresenterTextCaret (
+css::uno::Reference const& xContext,
 const ::std::function&
 rCharacterBoundsAccess,
 const ::std::function&
@@ -69,6 +70,7 @@ public:
 const css::awt::Rectangle& GetBounds() const;
 
 private:
+css::uno::Reference const& m_xContext;
 sal_Int32 mnParagraphIndex;
 sal_Int32 mnCharacterIndex;
 sal_Int32 mnCaretBlinkTaskId;
diff --git a/sdext/source/presenter/PresenterTimer.cxx 
b/sdext/source/presenter/PresenterTimer.cxx
index 4c18c07a2c79..0fba43273613 100644
--- a/sdext/source/presenter/PresenterTimer.cxx
+++ b/sdext/source/presenter/PresenterTimer.cxx
@@ -18,10 +18,15 @@
  */
 
 #include "PresenterTimer.hxx"
+
 #include 
 #include 
+#include 
+#include 
+
 #include 
 #include 
+#include 
 
 #include 
 #include 
@@ -70,7 +75,8 @@ class TimerScheduler
   public ::osl::Thread
 {
 public:
-static std::shared_ptr Instance();
+static std::shared_ptr Instance(
+uno::Reference const& xContext);
 static SharedTimerTask CreateTimerTask (
 const PresenterTimer::Task& rTask,
 const TimeValue& rDueTime,
@@ -89,6 +95,9 @@ public:
 static sal_Int64 ConvertFromTimeValue (
 const TimeValue& rTimeValue);
 
+static void NotifyTermination();
+static bo

[Libreoffice-commits] core.git: Repository.mk wizards/com wizards/CustomTarget_wizards.mk wizards/Module_wizards.mk wizards/Package_wizards.mk wizards/Package_wizards_properties.mk wizards/source

2017-05-24 Thread Caolán McNamara
 Repository.mk| 
   2 
 wizards/CustomTarget_wizards.mk  | 
  58 
 wizards/Module_wizards.mk| 
   3 
 wizards/Package_wizards.mk   | 
  16 
 wizards/Package_wizards_properties.mk| 
  16 
 wizards/com/sun/star/wizards/common/Configuration.java   | 
   5 
 wizards/com/sun/star/wizards/common/InvalidQueryException.java   | 
   6 
 wizards/com/sun/star/wizards/common/NoValidPathException.java| 
   4 
 wizards/com/sun/star/wizards/common/Resource.java| 
  90 
 wizards/com/sun/star/wizards/common/SystemDialog.java| 
   8 
 wizards/com/sun/star/wizards/db/CommandMetaData.java | 
   4 
 wizards/com/sun/star/wizards/db/DBMetaData.java  | 
   9 
 wizards/com/sun/star/wizards/document/GridControl.java   | 
   2 
 wizards/com/sun/star/wizards/document/TimeStampControl.java  | 
   4 
 wizards/com/sun/star/wizards/form/DataEntrySetter.java   | 
  12 
 wizards/com/sun/star/wizards/form/FieldLinker.java   | 
  16 
 wizards/com/sun/star/wizards/form/Finalizer.java | 
   8 
 wizards/com/sun/star/wizards/form/FormConfiguration.java | 
  10 
 wizards/com/sun/star/wizards/form/FormControlArranger.java   | 
   2 
 wizards/com/sun/star/wizards/form/FormWizard.java| 
  32 
 wizards/com/sun/star/wizards/form/StyleApplier.java  | 
  10 
 wizards/com/sun/star/wizards/form/UIControlArranger.java | 
  18 
 wizards/com/sun/star/wizards/query/Finalizer.java| 
  12 
 wizards/com/sun/star/wizards/query/QuerySummary.java | 
  32 
 wizards/com/sun/star/wizards/query/QueryWizard.java  | 
  22 
 wizards/com/sun/star/wizards/report/Dataimport.java  | 
  12 
 wizards/com/sun/star/wizards/report/GroupFieldHandler.java   | 
   4 
 wizards/com/sun/star/wizards/report/ReportFinalizer.java | 
  16 
 wizards/com/sun/star/wizards/report/ReportLayouter.java  | 
  26 
 wizards/com/sun/star/wizards/report/ReportTextDocument.java  | 
   2 
 wizards/com/sun/star/wizards/report/ReportTextImplementation.java| 
  68 
 wizards/com/sun/star/wizards/report/ReportWizard.java| 
  48 
 wizards/com/sun/star/wizards/reportbuilder/ReportBuilderImplementation.java  | 
   2 
 wizards/com/sun/star/wizards/reportbuilder/layout/ColumnarSingleColumn.java  | 
   2 
 wizards/com/sun/star/wizards/reportbuilder/layout/ColumnarThreeColumns.java  | 
   2 
 wizards/com/sun/star/wizards/reportbuilder/layout/ColumnarTwoColumns.java| 
   2 
 wizards/com/sun/star/wizards/reportbuilder/layout/InBlocksLabelsAbove.java   | 
   2 
 wizards/com/sun/star/wizards/reportbuilder/layout/InBlocksLabelsLeft.java| 
   2 
 wizards/com/sun/star/wizards/reportbuilder/layout/ReportBuilderLayouter.java | 
   8 
 wizards/com/sun/star/wizards/reportbuilder/layout/Tabular.java   | 
   2 
 wizards/com/sun/star/wizards/table/FieldFormatter.java   | 
  12 
 wizards/com/sun/star/wizards/table/Finalizer.java| 
  16 
 wizards/com/sun/star/wizards/table/PrimaryKeyHandler.java| 
  18 
 wizards/com/sun/star/wizards/table/ScenarioSelector.java | 
  12 
 wizards/com/sun/star/wizards/table/TableWizard.java  | 
  26 
 wizards/com/sun/star/wizards/ui/AggregateComponent.java  | 
  19 
 wizards/com/sun/star/wizards/ui/CommandFieldSelection.java   | 
   4 
 wizards/com/sun/star/wizards/ui/DBLimitedFieldSelection.java | 
   2 
 wizards/com/sun/star/wizards/ui/FieldSelection.java  | 
  12 
 wizards/com/sun/star/wizards/ui/FilterComponent.java | 
  25 
 wizards/com/sun/star/wizards/ui/SortingComponent.java| 
  28 
 wizards/com/sun/star/wizards/ui/UIConsts.java| 
   7 
 wizards/com/sun/star/wizards/ui/UIConsts.py  | 
   4 
 wizards/com/sun/star/wizards/ui/UnoDialog.java   | 
   4 
 wizards/com/sun/star/wizards/ui/WizardDialog.java| 
  30 
 wizards/source/formwizard/dbwizres.src   | 
1563 --
 wizards/source/resources/resources_en_US.properties  | 
 366 ++
 57 files changed, 815 inser

[Libreoffice-commits] online.git: loleaflet/debug loleaflet/main.js loleaflet/src

2017-05-24 Thread Henry Castro
 loleaflet/debug/document/loleaflet.html  |1 +
 loleaflet/main.js|3 +++
 loleaflet/src/control/Control.Menubar.js |6 +-
 3 files changed, 9 insertions(+), 1 deletion(-)

New commits:
commit 5d22b274f8cf8169e78489f770fecbd545174163
Author: Henry Castro 
Date:   Wed May 24 10:28:14 2017 -0400

loleaflet: add parameter to disable 'About' menu

Change-Id: I07fa655b8318f78d7e479a3dc34830ebe5f81a2e

diff --git a/loleaflet/debug/document/loleaflet.html 
b/loleaflet/debug/document/loleaflet.html
index 33364cea..f5462f84 100644
--- a/loleaflet/debug/document/loleaflet.html
+++ b/loleaflet/debug/document/loleaflet.html
@@ -106,6 +106,7 @@
 var permission = getParameterByName('permission') || 'edit';
 var timestamp = getParameterByName('timestamp');
 var closebutton = getParameterByName('closebutton');
+var disableAbout = getParameterByName('disableabout');
 if (wopiSrc === '' && filePath === '') {
 vex.dialog.alert(wrongwopisrc);
 }
diff --git a/loleaflet/main.js b/loleaflet/main.js
index 48200cd9..2fb44b3d 100644
--- a/loleaflet/main.js
+++ b/loleaflet/main.js
@@ -75,6 +75,8 @@ var closebutton = getParameterByName('closebutton');
 var revHistoryEnabled = getParameterByName('revisionhistory');
 // Should the document go inactive or not
 var alwaysActive = getParameterByName('alwaysactive');
+// Disable the about dialog
+var disableAbout = getParameterByName('disableabout');
 // Loleaflet Debug mode
 var debugMode = getParameterByName('debug');
 if (wopiSrc === '' && filePath === '') {
@@ -88,6 +90,7 @@ if (host === '') {
 // TODO: Get rid of these globals
 global.closebutton = closebutton;
 global.revHistoryEnabled = revHistoryEnabled;
+global.disableAbout = disableAbout;
 global.title = title;
 global.errorMessages = errorMessages;
 var docURL, docParams;
diff --git a/desktop/Library_deploymentgui.mk b/desktop/Library_deploymentgui.mk
index a16b567ea5d4..0a92e54d9907 100644
--- a/desktop/Library_deploymentgui.mk
+++ b/desktop/Library_deploymentgui.mk
@@ -20,6 +20,8 @@ $(eval $(call 
gb_Library_use_external,deploymentgui,boost_headers))
 
 $(eval $(call 
gb_Library_set_precompiled_header,deploymentgui,$(SRCDIR)/desktop/inc/pch/precompiled_deploymentgui))
 
+$(eval $(call gb_Library_use_custom_headers,deploymentgui,\ officecfg/registry 
\ ))
+
 $(eval $(call gb_Library_use_sdk_api,deploymentgui))
 
 $(eval $(call gb_Library_use_libraries,deploymentgui,\
diff --git a/desktop/inc/dp_gui.hrc b/desktop/inc/dp_gui.hrc
index 9bb961474743..b9c9c257bb63 100644
--- a/desktop/inc/dp_gui.hrc
+++ b/desktop/inc/dp_gui.hrc
@@ -30,6 +30,7 @@
 #define RID_STR_WARNING_VERSION_GREATER   
(RID_DEPLOYMENT_GUI_START + 7)
 #define RID_STR_WARNINGBOX_VERSION_GREATER_DIFFERENT_NAMES
(RID_DEPLOYMENT_GUI_START + 8)
 #define RID_STR_WARNING_INSTALL_EXTENSION 
(RID_DEPLOYMENT_GUI_START + 9)
+#define RID_STR_WARNING_INSTALL_EXTENSION_DISABLED
(RID_DEPLOYMENT_GUI_START + 10)
 
 #define RID_DLG_UPDATE_NONE (RID_DEPLOYMENT_GUI_START + 13)
 #define RID_DLG_UPDATE_NOINSTALLABLE(RID_DEPLOYMENT_GUI_START + 14)
diff --git a/desktop/source/deployment/gui/dp_gui_dialog.src 
b/desktop/source/deployment/gui/dp_gui_dialog.src
index 9078a353533a..5791c344a04d 100644
--- a/desktop/source/deployment/gui/dp_gui_dialog.src
+++ b/desktop/source/deployment/gui/dp_gui_dialog.src
@@ -113,6 +113,12 @@ String RID_STR_WARNING_INSTALL_EXTENSION
 "Click 'Cancel' to stop the installation.";
 };
 
+String RID_STR_WARNING_INSTALL_EXTENSION_DISABLED
+{
+Text [en-US] = "Extension installation is currently disabled. "
+"Please consult your system administrator for more information.";
+};
+
 String RID_STR_WARNING_REMOVE_EXTENSION
 {
 Text [en-US] = "You are about to remove the extension '%NAME'.\n"
diff --git a/desktop/source/deployment/gui/dp_gui_dialog2.cxx 
b/desktop/source/deployment/gui/dp_gui_dialog2.cxx
index dc75acbb8264..a2ce1d98bda3 100644
--- a/desktop/source/deployment/gui/dp_gui_dialog2.cxx
+++ b/desktop/source/deployment/gui/dp_gui_dialog2.cxx
@@ -71,6 +71,8 @@
 #include 
 #include 
 
+#include 
+
 #include 
 #include 
 #include 
@@ -419,6 +421,17 @@ void DialogHelper::openWebBrowser( const OUString & sURL, 
const OUString &sTitle
 bool DialogHelper::installExtensionWarn( const OUString &rExtensionName ) const
 {
 const SolarMutexGuard guard;
+
+// Check if extension installation is disabled in the expert configurations
+if 
(officecfg::Office::ExtensionManager::ExtensionSecurity::DisableExtensionInstallation::get())
+{
+ScopedVclPtrInstance aWarn(m_pVCLWindow, 
getResId(RID_STR_WARNING_INSTALL_EXTENSION_DISABLED),
+  VclMessageType::Warning, 
VclButtonsType::Ok);
+aWarn->Execute();
+
+return false;
+}
+
 ScopedVclPtrInstance aInfo(m_pVCLWindow, 
getResId(RID_STR_WARNING_INSTALL_EXTENSION),
   VclMessageType::Warning, 
VclButtonsType::OkCancel);
 
@@ -511,6 +524,12 @@ ExtMgrDialog::ExtMgrDialog(vcl::Window *pParent, 
TheExtensionManager *pManager,
 m_pUpdateBtn->Hide();
 #endif
 
+if 
(officecfg::Office::ExtensionManager::ExtensionSecurity::DisableExtensionInstallation::get())
+{
+m_pAddBtn->Disable();
+
m_pAddBtn->SetQuickHelpText(getResId(RID_STR_WARNING_INSTALL_EXTENSION_DISABLED));
+}
+
 m_aIdle.SetPriority(TaskPriority::LOWEST);
 m_aIdle.SetInvokeHandler( LINK( this, ExtMgrDialog, TimeOutHdl ) );
 }
@@ -804,7 +823,16 @@ IMPL_LINK( ExtMgrDialog, startProgress, void*, 
_bLockInterface, void )
 }
 
 m_pCancelBtn->E

[Libreoffice-commits] core.git: sc/inc

2017-05-24 Thread Tor Lillqvist
 sc/inc/formulacell.hxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit b3f058126b407e8f7d62e9ace68105f2b252e9ac
Author: Tor Lillqvist 
Date:   Wed May 24 15:51:18 2017 +0300

Clean up a comment

Change-Id: I9ee47a3de42087fb63e5d3e931ecee538017f3cc

diff --git a/sc/inc/formulacell.hxx b/sc/inc/formulacell.hxx
index d4cc6949aa48..b765afe0fd37 100644
--- a/sc/inc/formulacell.hxx
+++ b/sc/inc/formulacell.hxx
@@ -107,7 +107,7 @@ enum class ScMatrixMode : sal_uInt8 {
 class SC_DLLPUBLIC ScFormulaCell : public SvtListener
 {
 private:
-ScFormulaCellGroupRef mxGroup;   // re-factoring hack - group of 
formulae we're part of.
+ScFormulaCellGroupRef mxGroup;   // Group of formulae we're part of
 ScFormulaResult aResult;
 formula::FormulaGrammar::Grammar  eTempGrammar;   // used between string 
(creation) and (re)compilation
 ScTokenArray*   pCode;  // The (new) token array
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: external/liblangtag

2017-05-24 Thread Caolán McNamara
 external/liblangtag/UnpackedTarball_langtag.mk |1 
 external/liblangtag/langtag-valencia.patch.0   |   29 +
 2 files changed, 30 insertions(+)

New commits:
commit 18ef85fb86a4b0f356cb1d94270b2b6c6dab9161
Author: Caolán McNamara 
Date:   Wed May 24 11:50:09 2017 +0100

liblangtag#10 support roundtripping ca@valencia

Change-Id: I67932541fbb14316798fe94b64b4b32a3d1c29f6
Reviewed-on: https://gerrit.libreoffice.org/37984
Tested-by: Jenkins 
Reviewed-by: Caolán McNamara 
Tested-by: Caolán McNamara 

diff --git a/external/liblangtag/UnpackedTarball_langtag.mk 
b/external/liblangtag/UnpackedTarball_langtag.mk
index d8fccf261512..32cfd8685ab9 100644
--- a/external/liblangtag/UnpackedTarball_langtag.mk
+++ b/external/liblangtag/UnpackedTarball_langtag.mk
@@ -26,6 +26,7 @@ endif
 $(eval $(call gb_UnpackedTarball_add_patches,langtag, \
$(if 
$(SYSTEM_LIBXML),,external/liblangtag/langtag-libtool-rpath.patch.0) \
 external/liblangtag/clang-cl.patch.0 \
+external/liblangtag/langtag-valencia.patch.0 \
 ))
 
 # vim: set noet sw=4 ts=4:
diff --git a/external/liblangtag/langtag-valencia.patch.0 
b/external/liblangtag/langtag-valencia.patch.0
new file mode 100644
index ..dc28043042e4
--- /dev/null
+++ b/external/liblangtag/langtag-valencia.patch.0
@@ -0,0 +1,29 @@
+--- liblangtag/lt-tag.c
 liblangtag/lt-tag.c
+@@ -2009,11 +2009,23 @@
+   if (ctag->region)
+   lt_string_append_printf(string, "_%s",
+   lt_region_get_tag(ctag->region));
+-  if (ctag->script) {
++  if (ctag->script)
+   mod = lt_script_convert_to_modifier(ctag->script);
+-  if (mod)
+-  lt_string_append_printf(string, "@%s", mod);
++  if (!mod && ctag->variants)
++  {
++  lt_list_t* l;
++  for (l = ctag->variants; l != NULL; l = lt_list_next(l)) {
++  lt_variant_t *variant = lt_list_value(l);
++  const char *s = lt_variant_get_tag(variant);
++  if (lt_strcmp0(s, "valencia") == 0) {
++  mod = "valencia";
++  break;
++  }
++  }
+   }
++  if (mod)
++  lt_string_append_printf(string, "@%s", mod);
++
+   lt_tag_unref(ctag);
+ 
+   bail:
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


Re: Failing tests on openSUSE

2017-05-24 Thread Rene Engelhard
Hi,

On Wed, May 24, 2017 at 02:23:28PM +0200, Rene Engelhard wrote:
> On Wed, May 24, 2017 at 02:15:52PM +0200, Markus Mohrhard wrote:
> >All tests in master should pass a --with-fonts=no build. See e.g.
> >
> > [3]https://ci.libreoffice.org/job/lo_tb_random_config_linux/521/consoleFull
> 
> Apparently not, as this case showed. :)
> 
> You didn't happen to have dejavu installed somehow there?
> 
> (That patch already is in master and libreoffice-5-4 FTR)

https://ci.libreoffice.org/job/lo_tb_random_config_linux/521/consoleFull shows:

checking font mapping for 'Calibri'... configure: WARNING: unknown 
(Cantarell-Regular.otf)
checking font mapping for 'DejaVuSans'... ok
configure: WARNING: Unknown font mappings - unit tests disabled.

so it just happens to work(tm) given the missing of Calibri disables that test 
and
DejavuSans is there.

Regards,

Rene
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: Failing tests on openSUSE

2017-05-24 Thread Markus Mohrhard
Hey,

On Wed, May 24, 2017 at 2:23 PM, Rene Engelhard  wrote:

> Hi,
>
> On Wed, May 24, 2017 at 02:15:52PM +0200, Markus Mohrhard wrote:
> >All tests in master should pass a --with-fonts=no build. See e.g.
> >[3]https://ci.libreoffice.org/job/lo_tb_random_config_linux/
> 521/consoleFull
>
> Apparently not, as this case showed. :)
>
> You didn't happen to have dejavu installed somehow there?
>
> (That patch already is in master and libreoffice-5-4 FTR)
>
>

Oh interestingly SLES installs dejavu-fonts by default as the release note
package depends on it.

So we will not catch tests that only depend on dejavu-fonts with the CI job.

Markus
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: vcl/README.vars vcl/source

2017-05-24 Thread Miklos Vajna
 vcl/README.vars |1 
 vcl/source/filter/graphicfilter.cxx |   43 +---
 2 files changed, 41 insertions(+), 3 deletions(-)

New commits:
commit 0d860007d692f9fb15b5699b49c314eb72eae79b
Author: Miklos Vajna 
Date:   Wed May 24 10:08:25 2017 +0200

vcl: parallelize JPEG import from ImportGraphics()

Just the expensive, pixel reading part, not the bitmap creation, which
isn't thread-safe.

Change-Id: I3723d80aa29ee5f2e604800cb2061c59b0b0324d
Reviewed-on: https://gerrit.libreoffice.org/37978
Tested-by: Jenkins 
Reviewed-by: Miklos Vajna 

diff --git a/vcl/README.vars b/vcl/README.vars
index e97cf0d80697..e5b6f7b1c0f8 100644
--- a/vcl/README.vars
+++ b/vcl/README.vars
@@ -20,6 +20,7 @@ VCL_DEBUG_DISABLE_PDFCOMPRESSION - disable compression in the 
PDF writer
 Bitmap
 --
 VCL_NO_THREAD_SCALE - disable threaded bitmap scale
+VCL_NO_THREAD_IMPORT - disable threaded bitmap import
 EMF_PLUS_DISABLE - use EMF rendering and ignore EMF+ specifics
 
 OpenGL
diff --git a/vcl/source/filter/graphicfilter.cxx 
b/vcl/source/filter/graphicfilter.cxx
index c5bab5cd8891..d7eb5d7f7a4b 100644
--- a/vcl/source/filter/graphicfilter.cxx
+++ b/vcl/source/filter/graphicfilter.cxx
@@ -23,6 +23,7 @@
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 
@@ -1336,10 +1337,44 @@ struct GraphicImportContext
 GraphicFilterImportFlags m_nImportFlags = GraphicFilterImportFlags::NONE;
 };
 
+/// Graphic import worker that gets executed on a thread.
+class GraphicImportTask : public comphelper::ThreadTask
+{
+GraphicImportContext& m_rContext;
+public:
+GraphicImportTask(const std::shared_ptr& pTag, 
GraphicImportContext& rContext);
+void doWork() override;
+/// Shared code between threaded and non-threaded version.
+static void doImport(GraphicImportContext& rContext);
+};
+
+GraphicImportTask::GraphicImportTask(const 
std::shared_ptr& pTag, GraphicImportContext& 
rContext)
+: comphelper::ThreadTask(pTag),
+  m_rContext(rContext)
+{
+}
+
+void GraphicImportTask::doWork()
+{
+GraphicImportTask::doImport(m_rContext);
+}
+
+void GraphicImportTask::doImport(GraphicImportContext& rContext)
+{
+if (!ImportJPEG(*rContext.m_pStream, *rContext.m_pGraphic, 
rContext.m_nImportFlags | GraphicFilterImportFlags::UseExistingBitmap, 
rContext.m_pAccess.get()))
+rContext.m_nStatus = GRFILTER_FILTERERROR;
+else
+rContext.m_eLinkType = GfxLinkType::NativeJpg;
+}
+
 void GraphicFilter::ImportGraphics(std::vector< std::shared_ptr >& 
rGraphics, const std::vector< std::shared_ptr >& rStreams)
 {
+static bool bThreads = !getenv("VCL_NO_THREAD_IMPORT");
 std::vector aContexts;
 aContexts.reserve(rStreams.size());
+comphelper::ThreadPool& rSharedPool = 
comphelper::ThreadPool::getSharedOptimalPool();
+std::shared_ptr pTag = 
comphelper::ThreadPool::createThreadTaskTag();
+
 for (const auto& pStream : rStreams)
 {
 aContexts.push_back(GraphicImportContext());
@@ -1374,10 +1409,10 @@ void GraphicFilter::ImportGraphics(std::vector< 
std::shared_ptr >& rGra
 Bitmap& rBitmap = 
const_cast(rContext.m_pGraphic->GetBitmapExRef().GetBitmapRef());
 rContext.m_pAccess = 
o3tl::make_unique(rBitmap);
 pStream->Seek(rContext.m_nStreamBegin);
-if (!ImportJPEG(*pStream, *rContext.m_pGraphic, 
rContext.m_nImportFlags | GraphicFilterImportFlags::UseExistingBitmap, 
rContext.m_pAccess.get()))
-rContext.m_nStatus = GRFILTER_FILTERERROR;
+if (bThreads)
+rSharedPool.pushTask(new GraphicImportTask(pTag, 
rContext));
 else
-rContext.m_eLinkType = GfxLinkType::NativeJpg;
+GraphicImportTask::doImport(rContext);
 }
 }
 else
@@ -1386,6 +1421,8 @@ void GraphicFilter::ImportGraphics(std::vector< 
std::shared_ptr >& rGra
 }
 }
 
+rSharedPool.waitUntilDone(pTag);
+
 // Process data after import.
 for (auto& rContext : aContexts)
 {
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: Branch 'libreoffice-5-4' - sw/source

2017-05-24 Thread Szymon Kłos
 sw/source/core/edit/edfcol.cxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit a61d03c2fffc882a8619e293034f1432b4099de4
Author: Szymon Kłos 
Date:   Wed May 24 12:59:26 2017 +0200

tdf#108040 Don't turn on header to check if Watermark exist

Change-Id: Ieaf42384248deb283f71743f68c059b384abaa1a
Reviewed-on: https://gerrit.libreoffice.org/37985
Tested-by: Jenkins 
Reviewed-by: Szymon Kłos 

diff --git a/sw/source/core/edit/edfcol.cxx b/sw/source/core/edit/edfcol.cxx
index c39ccadf3f81..4ffbd1263864 100644
--- a/sw/source/core/edit/edfcol.cxx
+++ b/sw/source/core/edit/edfcol.cxx
@@ -277,7 +277,7 @@ SfxWatermarkItem SwEditShell::GetWatermark()
 bool bHeaderIsOn = false;
 xPageStyle->getPropertyValue(UNO_NAME_HEADER_IS_ON) >>= bHeaderIsOn;
 if (!bHeaderIsOn)
-xPageStyle->setPropertyValue(UNO_NAME_HEADER_IS_ON, 
uno::makeAny(true));
+return SfxWatermarkItem();
 
 uno::Reference xHeaderText;
 xPageStyle->getPropertyValue(UNO_NAME_HEADER_TEXT) >>= xHeaderText;
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


Re: Failing tests on openSUSE

2017-05-24 Thread Markus Mohrhard
Hey,

On Mon, May 22, 2017 at 4:22 PM, Rene Engelhard  wrote:

> On Mon, May 22, 2017 at 12:55:56PM +0200, Khaled Hosny wrote:
> > On Mon, May 22, 2017 at 12:36:26PM +0200, Rene Engelhard wrote:
> > > Hi,
> > >
> > > On Mon, May 22, 2017 at 11:38:43AM +0200, Khaled Hosny wrote:
> > > > The test (naďvely?) assumes DejaVu Sans is always present since it is
> > > > one of the bundled fonts, if this is not true since the test needs
> to be
> > > > conditionally enabled somehow.
> > >
> > > Maybe check it like the other fonts? If --without-fonts is specified
> that is.
> > > See https://cgit.freedesktop.org/libreoffice/core/tree/
> configure.ac#n11251 ff.
> >
> > That would do it I think.
>
> This patch should do it. (Just tested configure for now)
>
> Regards,
>


All tests in master should pass a --with-fonts=no build. See e.g.
https://ci.libreoffice.org/job/lo_tb_random_config_linux/521/consoleFull

I think I disabled all tests that depend on the additional fonts for the
random config CI build.

Regards,
Markus
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: sw/source

2017-05-24 Thread Szymon Kłos
 sw/source/core/edit/edfcol.cxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 6e01993a420912ab8896879b0b91c47c3479c239
Author: Szymon Kłos 
Date:   Wed May 24 12:59:26 2017 +0200

tdf#108040 Don't turn on header to check if Watermark exist

Change-Id: Ieaf42384248deb283f71743f68c059b384abaa1a

diff --git a/sw/source/core/edit/edfcol.cxx b/sw/source/core/edit/edfcol.cxx
index c39ccadf3f81..4ffbd1263864 100644
--- a/sw/source/core/edit/edfcol.cxx
+++ b/sw/source/core/edit/edfcol.cxx
@@ -277,7 +277,7 @@ SfxWatermarkItem SwEditShell::GetWatermark()
 bool bHeaderIsOn = false;
 xPageStyle->getPropertyValue(UNO_NAME_HEADER_IS_ON) >>= bHeaderIsOn;
 if (!bHeaderIsOn)
-xPageStyle->setPropertyValue(UNO_NAME_HEADER_IS_ON, 
uno::makeAny(true));
+return SfxWatermarkItem();
 
 uno::Reference xHeaderText;
 xPageStyle->getPropertyValue(UNO_NAME_HEADER_TEXT) >>= xHeaderText;
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


Ana Isabel license statement

2017-05-24 Thread A. Isabel
All of my past & future contributions to LibreOffice may be licensed
under the MPLv2/LGPLv3+ dual license.
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: accessibility/inc compilerplugins/clang

2017-05-24 Thread Noel Grandin
 accessibility/inc/standard/accessiblemenubasecomponent.hxx |3 
 compilerplugins/clang/unusedfields.untouched.results   |2 
 compilerplugins/clang/unusedfields.writeonly.results   |   66 +
 3 files changed, 27 insertions(+), 44 deletions(-)

New commits:
commit 0a58848fddbcc4a3fafe3ddb4fdfbb4feda73b30
Author: Noel Grandin 
Date:   Wed May 24 12:04:26 2017 +0200

loplugin:unusedfields

Change-Id: Ib91c6d23a1af3735d9c030eaf9efae817f513c58
Reviewed-on: https://gerrit.libreoffice.org/37982
Tested-by: Jenkins 
Reviewed-by: Noel Grandin 

diff --git a/accessibility/inc/standard/accessiblemenubasecomponent.hxx 
b/accessibility/inc/standard/accessiblemenubasecomponent.hxx
index ba401354f810..96fa054244c2 100644
--- a/accessibility/inc/standard/accessiblemenubasecomponent.hxx
+++ b/accessibility/inc/standard/accessiblemenubasecomponent.hxx
@@ -54,9 +54,6 @@ class OAccessibleMenuBaseComponent : private 
BaseVCLExternalSolarLock,
 friend class VCLXAccessibleMenuItem;
 friend class VCLXAccessibleMenu;
 
-private:
-VCLExternalSolarLock*   m_pExternalLock;
-
 protected:
 typedef std::vector< css::uno::Reference< css::accessibility::XAccessible 
> > AccessibleChildren;
 
diff --git a/compilerplugins/clang/unusedfields.untouched.results 
b/compilerplugins/clang/unusedfields.untouched.results
index 0803a2ea6cc4..d8980b949a45 100644
--- a/compilerplugins/clang/unusedfields.untouched.results
+++ b/compilerplugins/clang/unusedfields.untouched.results
@@ -165,7 +165,7 @@ sfx2/source/doc/doctempl.cxx:119
 starmath/inc/view.hxx:224
 SmViewShell maGraphicController class SmGraphicController
 svtools/source/svhtml/htmlkywd.cxx:558
-HTML_OptionEntry  union HTML_OptionEntry::(anonymous at 
/home/noel/libo2/svtools/source/svhtml/htmlkywd.cxx:558:5)
+HTML_OptionEntry  union HTML_OptionEntry::(anonymous at 
/home/noel/libo3/svtools/source/svhtml/htmlkywd.cxx:558:5)
 svtools/source/svhtml/htmlkywd.cxx:560
 HTML_OptionEntry::(anonymous) sToken const sal_Char *
 svtools/source/svhtml/htmlkywd.cxx:561
diff --git a/compilerplugins/clang/unusedfields.writeonly.results 
b/compilerplugins/clang/unusedfields.writeonly.results
index e4243a5f38ed..609697446996 100644
--- a/compilerplugins/clang/unusedfields.writeonly.results
+++ b/compilerplugins/clang/unusedfields.writeonly.results
@@ -454,39 +454,39 @@ hwpfilter/source/hbox.h:884
 TocMark kind hchar
 hwpfilter/source/hbox.h:902
 IndexMark pgno unsigned short
-hwpfilter/source/hinfo.h:72
-PaperBackInfo luminance int
 hwpfilter/source/hinfo.h:73
-PaperBackInfo contrast int
+PaperBackInfo luminance int
 hwpfilter/source/hinfo.h:74
+PaperBackInfo contrast int
+hwpfilter/source/hinfo.h:75
 PaperBackInfo effect char
-hwpfilter/source/hinfo.h:108
-DocChainInfo chain_page_no unsigned char
 hwpfilter/source/hinfo.h:109
+DocChainInfo chain_page_no unsigned char
+hwpfilter/source/hinfo.h:110
 DocChainInfo chain_footnote_no unsigned char
-hwpfilter/source/hinfo.h:154
+hwpfilter/source/hinfo.h:155
 HWPInfo cur_col short
-hwpfilter/source/hinfo.h:158
+hwpfilter/source/hinfo.h:159
 HWPInfo cur_row short
-hwpfilter/source/hinfo.h:168
+hwpfilter/source/hinfo.h:169
 HWPInfo readonly short
-hwpfilter/source/hinfo.h:173
+hwpfilter/source/hinfo.h:174
 HWPInfo chain_info struct DocChainInfo
-hwpfilter/source/hinfo.h:182
+hwpfilter/source/hinfo.h:183
 HWPInfo countfn short
-hwpfilter/source/hinfo.h:185
+hwpfilter/source/hinfo.h:186
 HWPInfo fnchar unsigned char
-hwpfilter/source/hinfo.h:194
-HWPInfo empty_line_hide unsigned char
 hwpfilter/source/hinfo.h:195
+HWPInfo empty_line_hide unsigned char
+hwpfilter/source/hinfo.h:196
 HWPInfo table_move unsigned char
-hwpfilter/source/hinfo.h:197
+hwpfilter/source/hinfo.h:198
 HWPInfo reserved3 unsigned char
-hwpfilter/source/hinfo.h:233
+hwpfilter/source/hinfo.h:234
 CharShape reserved unsigned char [4]
-hwpfilter/source/hinfo.h:277
+hwpfilter/source/hinfo.h:278
 ParaShape condense unsigned char
-hwpfilter/source/hinfo.h:283
+hwpfilter/source/hinfo.h:284
 ParaShape outline_continue unsigned char
 hwpfilter/source/hpara.h:61
 LineInfo pos unsigned short
@@ -688,19 +688,9 @@ include/xmloff/maptype.hxx:88
 XMLPropertyMapEntry mnContextId sal_Int16
 include/xmloff/maptype.hxx:89
 XMLPropertyMapEntry mnEarliestODFVersionForExport class 
SvtSaveOptions::ODFDefaultVersion
-lingucomponent/source/languageguessing/simpleguesser.cxx:76
-ngram_t rank sint2
-lingucomponent/source/languageguessing/simpleguesser.cxx:77
-ngram_t str char [21]
-lingucomponent/source/languageguessing/simpleguesser.cxx:83
-fp_t name const char *
-lingucomponent/source/languageguessing/simpleguesser.cxx:84
-fp_t fprint ngram_t *
-lingucomponent/source/languageguessing/simpleguesser.cxx:85
-fp_t size uint4
-lingucomponent/source/languageguessing/simpleguesser.cxx:94
+lingucomponent/source/languageguessing/s

[Libreoffice-commits] core.git: Branch 'libreoffice-5-4' - include/tools svx/source

2017-05-24 Thread Yousuf Philips
 include/tools/colordata.hxx|2 ++
 svx/source/tbxctrls/tbxcolorupdate.cxx |4 ++--
 2 files changed, 4 insertions(+), 2 deletions(-)

New commits:
commit 7a32cd3c13d822171a65c955ccbbe6176d76940e
Author: Yousuf Philips 
Date:   Tue May 23 03:22:28 2017 +0400

tdf#107731 New default red and yellow for font and highlight color

Change-Id: Ide81a7a3fce963a13b5c65861f566878ccb15676
Reviewed-on: https://gerrit.libreoffice.org/37884
Tested-by: Jenkins 
Reviewed-by: Maxim Monastirsky 
(cherry picked from commit 318ba58031f656beda5a735d687a0ba991d9d779)
Reviewed-on: https://gerrit.libreoffice.org/37972

diff --git a/include/tools/colordata.hxx b/include/tools/colordata.hxx
index c303957411df..3df26b57092b 100644
--- a/include/tools/colordata.hxx
+++ b/include/tools/colordata.hxx
@@ -46,6 +46,7 @@ constexpr ColorData RGB_COLORDATA(sal_uInt8 r, sal_uInt8 g, 
sal_uInt8 b) {
 #define COL_GREEN   RGB_COLORDATA( 0x00, 0x80, 0x00 )
 #define COL_CYANRGB_COLORDATA( 0x00, 0x80, 0x80 )
 #define COL_RED RGB_COLORDATA( 0x80, 0x00, 0x00 )
+#define COL_RED_FONTCOLOR   RGB_COLORDATA( 0xCE, 0x18, 0x1E )
 #define COL_MAGENTA RGB_COLORDATA( 0x80, 0x00, 0x80 )
 #define COL_BROWN   RGB_COLORDATA( 0x80, 0x80, 0x00 )
 #define COL_GRAYRGB_COLORDATA( 0x80, 0x80, 0x80 )
@@ -59,6 +60,7 @@ constexpr ColorData RGB_COLORDATA(sal_uInt8 r, sal_uInt8 g, 
sal_uInt8 b) {
 #define COL_LIGHTMAGENTARGB_COLORDATA( 0xFF, 0x00, 0xFF )
 #define COL_LIGHTGRAYBLUE   RGB_COLORDATA( 0xE0, 0xE0, 0xFF )
 #define COL_YELLOW  RGB_COLORDATA( 0xFF, 0xFF, 0x00 )
+#define COL_YELLOW_HIGHLIGHTRGB_COLORDATA( 0xFF, 0xF2, 0x00 )
 #define COL_WHITE   RGB_COLORDATA( 0xFF, 0xFF, 0xFF )
 #define COL_TRANSPARENT TRGB_COLORDATA( 0xFF, 0xFF, 0xFF, 0xFF )
 #define COL_AUTO(ColorData)0x
diff --git a/svx/source/tbxctrls/tbxcolorupdate.cxx 
b/svx/source/tbxctrls/tbxcolorupdate.cxx
index 157b65db6318..56cff24bc5df 100644
--- a/svx/source/tbxctrls/tbxcolorupdate.cxx
+++ b/svx/source/tbxctrls/tbxcolorupdate.cxx
@@ -42,7 +42,7 @@ namespace svx
 {
 case SID_ATTR_CHAR_COLOR:
 case SID_ATTR_CHAR_COLOR2:
-Update(COL_RED);
+Update(COL_RED_FONTCOLOR);
 break;
 case SID_FRAME_LINECOLOR:
 Update(COL_BLUE);
@@ -50,7 +50,7 @@ namespace svx
 case SID_ATTR_CHAR_COLOR_BACKGROUND:
 case SID_ATTR_CHAR_BACK_COLOR:
 case SID_BACKGROUND_COLOR:
-Update(COL_YELLOW);
+Update(COL_YELLOW_HIGHLIGHT);
 break;
 case SID_ATTR_LINE_COLOR:
 Update(COL_DEFAULT_SHAPE_STROKE);
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


Re: Failing tests on openSUSE

2017-05-24 Thread Rene Engelhard
Hi,

On Mon, May 22, 2017 at 11:38:43AM +0200, Khaled Hosny wrote:
> The test (naïvely?) assumes DejaVu Sans is always present since it is
> one of the bundled fonts, if this is not true since the test needs to be
> conditionally enabled somehow.

Maybe check it like the other fonts? If --without-fonts is specified that is.
See https://cgit.freedesktop.org/libreoffice/core/tree/configure.ac#n11251 ff.

Regards,

Rene
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: Failing tests on openSUSE

2017-05-24 Thread Rene Engelhard
On Mon, May 22, 2017 at 12:55:56PM +0200, Khaled Hosny wrote:
> On Mon, May 22, 2017 at 12:36:26PM +0200, Rene Engelhard wrote:
> > Hi,
> > 
> > On Mon, May 22, 2017 at 11:38:43AM +0200, Khaled Hosny wrote:
> > > The test (naïvely?) assumes DejaVu Sans is always present since it is
> > > one of the bundled fonts, if this is not true since the test needs to be
> > > conditionally enabled somehow.
> > 
> > Maybe check it like the other fonts? If --without-fonts is specified that 
> > is.
> > See https://cgit.freedesktop.org/libreoffice/core/tree/configure.ac#n11251 
> > ff.
> 
> That would do it I think.

This patch should do it. (Just tested configure for now)

Regards,

Rene
--- libreoffice-5.4.0.0.beta1/vcl/qa/cppunit/complextext.cxx	2017-05-18 12:48:14.0 +0200
+++ tmp/libreoffice-5.4.0.0.beta1/vcl/qa/cppunit/complextext.cxx	2017-05-22 15:23:13.668459293 +0200
@@ -19,6 +19,8 @@
 #include 
 #include 
 
+#include 
+
 std::ostream& operator<<(std::ostream& rStream, const std::vector& rVec)
 {
 rStream << "{ ";
@@ -41,13 +43,16 @@
 #endif
 
 CPPUNIT_TEST_SUITE(VclComplexTextTest);
+#if !TEST_FONTS_MISSING
 CPPUNIT_TEST(testArabic);
+#endif
 #if defined(_WIN32)
 CPPUNIT_TEST(testTdf95650);
 #endif
 CPPUNIT_TEST_SUITE_END();
 };
 
+#if !TEST_FONTS_MISSING
 void VclComplexTextTest::testArabic()
 {
 const unsigned char pOneTwoThreeUTF8[] = {
@@ -121,6 +126,7 @@
 (void)aRect; (void)aRectRot;
 #endif
 }
+#endif
 
 #if defined(_WIN32)
 void VclComplexTextTest::testTdf95650()
--- libreoffice-5.4.0.0.beta1/configure.ac	2017-05-18 12:48:14.0 +0200
+++ tmp/libreoffice-5.4.0.0.beta1/configure.ac	2017-05-22 15:51:26.406507002 +0200
@@ -11290,7 +11289,8 @@
 then
 AC_MSG_RESULT([ok])
 else
-AC_MSG_RESULT([unknown ($FONTFILE)])
+AC_MSG_WARN([unknown ($FONTFILE)])
+add_warning "unknown ($FONTFILE)"
 TEST_FONTS_MISSING=1
 fi
 }
@@ -11315,9 +11315,11 @@
 TEST_FONTS_MISSING=1
 else
 test_font_map 'Calibri' 'Carlito'
+test_font_map 'DejaVuSans' 'DejaVuSans'
 if test ${TEST_FONTS_MISSING} -eq 1
 then
 AC_MSG_WARN([Unknown font mappings - unit tests disabled.])
+add_warning "Unknown font mappings - unit tests disabled."
 fi
 fi
 else
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] help.git: Branch 'libreoffice-5-4' - source/text

2017-05-24 Thread Olivier Hallot
 source/text/shared/01/05020301.xhp |  408 ++---
 1 file changed, 204 insertions(+), 204 deletions(-)

New commits:
commit 7dae48c4a4c4deac188cba54357fd4d1698ae966
Author: Olivier Hallot 
Date:   Wed May 24 00:01:54 2017 -0300

Mute l10n for dozens of numbers and format codes

Muted numbers and codes are not to be translated

Change-Id: I4714318c6108a2735825d7ff7832d2b3733df7f7
Reviewed-on: https://gerrit.libreoffice.org/37974
Reviewed-by: Olivier Hallot 
Tested-by: Olivier Hallot 

diff --git a/source/text/shared/01/05020301.xhp 
b/source/text/shared/01/05020301.xhp
index d2db2494a..1a948ccc9 100644
--- a/source/text/shared/01/05020301.xhp
+++ b/source/text/shared/01/05020301.xhp
@@ -80,7 +80,7 @@
   
   
 
-  #
+  #
 
 
   Does 
not display extra zeros.
@@ -88,7 +88,7 @@
   
   
 
-  ?
+  ?
 
 
   Displays space characters instead of extra zeros.
@@ -121,7 +121,7 @@
   3456.78 as 3456.8
 
 
-  .#
+  .#
 
   
   
@@ -129,7 +129,7 @@
   9.9 
as 9.900
 
 
-  #.000
+  #.000
 
   
   
@@ -137,7 +137,7 @@
   13 as 
13.0 and 1234.567 as 1234.57
 
 
-  #.0#
+  #.0#
 
   
   
@@ -145,7 +145,7 @@
   5.75 
as 5 3/4 and 6.3 as 6 3/10
 
 
-  # 
???/???
+  # ???/???
 
   
   
@@ -153,7 +153,7 @@
   .5 as 
0.5
 
 
-  0.##
+  0.##
 
   
   
@@ -161,7 +161,7 @@
   .5 as 
0.5   (with two extra spaces at the end)
 
 
-  0.???
+  0.???
 
   
 
@@ -184,7 +184,7 @@
   15000 
as 15,000
 
 
-  #,###
+  #,###
 
   
   
@@ -192,7 +192,7 @@
   16000 
as 16
 
 
-  #,
+  #,
 
   
 
@@ -209,9 +209,9 @@
 Spaces
 To use a 
character to define the width of a space in a number format, type an underscore 
( _ ) followed by the character. The width of the space varies according to the 
width of the character that you choose. For example, _M creates a 
wider space than _i.
 To fill free 
space with a given character, use an asterisk (*) followed by this character. 
For instance:
-*\0
+*\0
 will display 
integer value (0) preceded by as many as needed backslash characters (\) to 
fill column width. For accounting representation, you may left align currency 
symbol with a format similar to:
-$_-* 0.--;$-* 
0.--;$_-* -
+$_-* 0.--;$-* 0.--;$_-* -
 
 Color
 To set the 
color of a section of a number format code, insert one of the following color 
names in square brackets [ ]:
@@ -219,34 +219,34 @@
 
   
 
-  CYAN
+  CYAN
 
 
-  GREEN
+  GREEN
 
   
   
 
-  BLACK
+  BLACK
 
 
-  BLUE
+  BLUE
 
   
   
 
-  MAGENTA
+  MAGENTA
 
 
-  RED
+  RED
 
   
   
 
-  WHITE
+  WHITE
 
 
-  YELLOW
+  YELLOW
 
   
 
@@ -258,7 +258,7 @@
 You can define 
a number format so that it only applies when the condition that you specify is 
met. Conditions are enclosed by square brackets [ ].
 You can use 
any combination of numbers and the <, <=, >, >=, = and <> 
operators.
 For example, 
if you want to apply different colors to different temperature data, 
enter:
-[BLUE][<0]#.0 
"°C";[RED][>30]#.0 "°C";[BLACK]#.0 "°C"
+[BLUE][<0]#.0 "°C";[RED][>30]#.0 "°C";[BLACK]#.0 
"°C"
 All 
temperatures below zero are blue, temperatures between 0 and 30 °C are black, 
and temperatures higher than 30 °C are red.
 
 Positive and Negative Numbers
@@ -271,14 +271,14 @@
 To display 
numbers as percentages, add the percent sign (%) to the number 
format.
 
 Scientific Notation
-Scientific 
notation lets you write very large numbers or very small fractions in a compact 
form. For example, in scientific notation, 65 is written as 6.5 x 
105, and 0.65 as 6.5 x 10-5. Translators: 
use the decimal delimiter of your language (period or comma) for all number 
format codes in Calc.In %PRODUCTNAME, 
these numbers are written as 6.5E+5 and 6.5E-5, respectively. To create a 
number format that displays numbers using scientific notation, enter a # or 0, 
and then one of the following codes E-, E+, e- or e+. If sign is omitted after 
E or e, it won't appear for positive value of exponent. To get engineering 
notation, enter 3 digits (0 or #) in the integer part: ###.##E+00 
for instance.
+Scientific 
notation lets you write very large numbers or very small fractions in a compact 
form. For example, in scientific notation, 65 is written as 6.5 x 105, and 
0.65 as 6.5 x 10-5. Translators: use the decimal delimiter of your 
language (period or comma) for all number format codes in Calc.In 
%PRODUCTNAME, these numbers are written as 
6.5E+5 and 6.5E-5, respectively. To create a number format that displays 
numbers using scientific notation, enter a # or 0, and then one of the 
following codes E-, E+, e- or e+. If sign is omitted after E or e, 

[Libreoffice-commits] core.git: Branch 'libreoffice-5-4' - helpcontent2

2017-05-24 Thread Olivier Hallot
 helpcontent2 |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit e4bd6074adb542aab363b8360e0efaf8470963de
Author: Olivier Hallot 
Date:   Wed May 24 00:01:54 2017 -0300

Updated core
Project: help  7dae48c4a4c4deac188cba54357fd4d1698ae966

Mute l10n for dozens of numbers and format codes

Muted numbers and codes are not to be translated

Change-Id: I4714318c6108a2735825d7ff7832d2b3733df7f7
Reviewed-on: https://gerrit.libreoffice.org/37974
Reviewed-by: Olivier Hallot 
Tested-by: Olivier Hallot 

diff --git a/helpcontent2 b/helpcontent2
index 155917c717d4..7dae48c4a4c4 16
--- a/helpcontent2
+++ b/helpcontent2
@@ -1 +1 @@
-Subproject commit 155917c717d4a581b7792fceb5080eaa605bcc9d
+Subproject commit 7dae48c4a4c4deac188cba54357fd4d1698ae966
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: helpcontent2

2017-05-24 Thread Olivier Hallot
 helpcontent2 |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 0bfddd99a28ebdf5b690c224df3feb2498758c0a
Author: Olivier Hallot 
Date:   Wed May 24 00:01:54 2017 -0300

Updated core
Project: help  cc225764fb26219e24b0f1aa73c2a9f55e4a65e1

Mute l10n for dozens of numbers and format codes

Muted numbers and codes are not to be translated

Change-Id: I4714318c6108a2735825d7ff7832d2b3733df7f7
Reviewed-on: https://gerrit.libreoffice.org/37973
Reviewed-by: Olivier Hallot 
Tested-by: Olivier Hallot 

diff --git a/helpcontent2 b/helpcontent2
index 9c0f31652cb8..cc225764fb26 16
--- a/helpcontent2
+++ b/helpcontent2
@@ -1 +1 @@
-Subproject commit 9c0f31652cb806846bad8f814006209489c58b6b
+Subproject commit cc225764fb26219e24b0f1aa73c2a9f55e4a65e1
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] help.git: source/text

2017-05-24 Thread Olivier Hallot
 source/text/shared/01/05020301.xhp |  408 ++---
 1 file changed, 204 insertions(+), 204 deletions(-)

New commits:
commit cc225764fb26219e24b0f1aa73c2a9f55e4a65e1
Author: Olivier Hallot 
Date:   Wed May 24 00:01:54 2017 -0300

Mute l10n for dozens of numbers and format codes

Muted numbers and codes are not to be translated

Change-Id: I4714318c6108a2735825d7ff7832d2b3733df7f7
Reviewed-on: https://gerrit.libreoffice.org/37973
Reviewed-by: Olivier Hallot 
Tested-by: Olivier Hallot 

diff --git a/source/text/shared/01/05020301.xhp 
b/source/text/shared/01/05020301.xhp
index d2db2494a..1a948ccc9 100644
--- a/source/text/shared/01/05020301.xhp
+++ b/source/text/shared/01/05020301.xhp
@@ -80,7 +80,7 @@
   
   
 
-  #
+  #
 
 
   Does 
not display extra zeros.
@@ -88,7 +88,7 @@
   
   
 
-  ?
+  ?
 
 
   Displays space characters instead of extra zeros.
@@ -121,7 +121,7 @@
   3456.78 as 3456.8
 
 
-  .#
+  .#
 
   
   
@@ -129,7 +129,7 @@
   9.9 
as 9.900
 
 
-  #.000
+  #.000
 
   
   
@@ -137,7 +137,7 @@
   13 as 
13.0 and 1234.567 as 1234.57
 
 
-  #.0#
+  #.0#
 
   
   
@@ -145,7 +145,7 @@
   5.75 
as 5 3/4 and 6.3 as 6 3/10
 
 
-  # 
???/???
+  # ???/???
 
   
   
@@ -153,7 +153,7 @@
   .5 as 
0.5
 
 
-  0.##
+  0.##
 
   
   
@@ -161,7 +161,7 @@
   .5 as 
0.5   (with two extra spaces at the end)
 
 
-  0.???
+  0.???
 
   
 
@@ -184,7 +184,7 @@
   15000 
as 15,000
 
 
-  #,###
+  #,###
 
   
   
@@ -192,7 +192,7 @@
   16000 
as 16
 
 
-  #,
+  #,
 
   
 
@@ -209,9 +209,9 @@
 Spaces
 To use a 
character to define the width of a space in a number format, type an underscore 
( _ ) followed by the character. The width of the space varies according to the 
width of the character that you choose. For example, _M creates a 
wider space than _i.
 To fill free 
space with a given character, use an asterisk (*) followed by this character. 
For instance:
-*\0
+*\0
 will display 
integer value (0) preceded by as many as needed backslash characters (\) to 
fill column width. For accounting representation, you may left align currency 
symbol with a format similar to:
-$_-* 0.--;$-* 
0.--;$_-* -
+$_-* 0.--;$-* 0.--;$_-* -
 
 Color
 To set the 
color of a section of a number format code, insert one of the following color 
names in square brackets [ ]:
@@ -219,34 +219,34 @@
 
   
 
-  CYAN
+  CYAN
 
 
-  GREEN
+  GREEN
 
   
   
 
-  BLACK
+  BLACK
 
 
-  BLUE
+  BLUE
 
   
   
 
-  MAGENTA
+  MAGENTA
 
 
-  RED
+  RED
 
   
   
 
-  WHITE
+  WHITE
 
 
-  YELLOW
+  YELLOW
 
   
 
@@ -258,7 +258,7 @@
 You can define 
a number format so that it only applies when the condition that you specify is 
met. Conditions are enclosed by square brackets [ ].
 You can use 
any combination of numbers and the <, <=, >, >=, = and <> 
operators.
 For example, 
if you want to apply different colors to different temperature data, 
enter:
-[BLUE][<0]#.0 
"°C";[RED][>30]#.0 "°C";[BLACK]#.0 "°C"
+[BLUE][<0]#.0 "°C";[RED][>30]#.0 "°C";[BLACK]#.0 
"°C"
 All 
temperatures below zero are blue, temperatures between 0 and 30 °C are black, 
and temperatures higher than 30 °C are red.
 
 Positive and Negative Numbers
@@ -271,14 +271,14 @@
 To display 
numbers as percentages, add the percent sign (%) to the number 
format.
 
 Scientific Notation
-Scientific 
notation lets you write very large numbers or very small fractions in a compact 
form. For example, in scientific notation, 65 is written as 6.5 x 
105, and 0.65 as 6.5 x 10-5. Translators: 
use the decimal delimiter of your language (period or comma) for all number 
format codes in Calc.In %PRODUCTNAME, 
these numbers are written as 6.5E+5 and 6.5E-5, respectively. To create a 
number format that displays numbers using scientific notation, enter a # or 0, 
and then one of the following codes E-, E+, e- or e+. If sign is omitted after 
E or e, it won't appear for positive value of exponent. To get engineering 
notation, enter 3 digits (0 or #) in the integer part: ###.##E+00 
for instance.
+Scientific 
notation lets you write very large numbers or very small fractions in a compact 
form. For example, in scientific notation, 65 is written as 6.5 x 105, and 
0.65 as 6.5 x 10-5. Translators: use the decimal delimiter of your 
language (period or comma) for all number format codes in Calc.In 
%PRODUCTNAME, these numbers are written as 
6.5E+5 and 6.5E-5, respectively. To create a number format that displays 
numbers using scientific notation, enter a # or 0, and then one of the 
following codes E-, E+, e- or e+. If sign is omitted after E or e, 

[Libreoffice-commits] core.git: officecfg/registry

2017-05-24 Thread Andras Timar
 officecfg/registry/data/org/openoffice/Office/UI/WriterCommands.xcu |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 439cdc8530fef0d7e1a62a66c094a27af2181309
Author: Andras Timar 
Date:   Wed May 24 11:02:14 2017 +0200

Watermark command opens a dialog, add ... to the label

Change-Id: I274661b1ec892425d84cd72194c376e498bf70ed

diff --git 
a/officecfg/registry/data/org/openoffice/Office/UI/WriterCommands.xcu 
b/officecfg/registry/data/org/openoffice/Office/UI/WriterCommands.xcu
index 96f2ba909a51..73361c870388 100644
--- a/officecfg/registry/data/org/openoffice/Office/UI/WriterCommands.xcu
+++ b/officecfg/registry/data/org/openoffice/Office/UI/WriterCommands.xcu
@@ -2933,7 +2933,7 @@
   
   
 
-  Watermark
+  Watermark...
 
 
   1
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: Branch 'libreoffice-5-3' - include/vcl vcl/inc vcl/source vcl/unx

2017-05-24 Thread Caolán McNamara
 include/vcl/commandevent.hxx   |6 -
 include/vcl/window.hxx |2 
 vcl/inc/salwtype.hxx   |2 
 vcl/inc/unx/gtk/gtkframe.hxx   |9 ++
 vcl/source/window/commandevent.cxx |4 -
 vcl/source/window/window2.cxx  |   14 +--
 vcl/unx/gtk/gtksalframe.cxx|   15 ++--
 vcl/unx/gtk3/gtk3gtkframe.cxx  |  137 +
 8 files changed, 126 insertions(+), 63 deletions(-)

New commits:
commit f7d2bf216afa10268e6a7c1d4613a2fd8f7c7f3c
Author: Caolán McNamara 
Date:   Tue May 16 10:12:09 2017 +0100

Resolves: tdf#103174 & rhbz#1367846 improve gtk3 trackpad scrolling

convert number of "lines" scrolled to double and allow
fractional parts of lines/columns

Change-Id: Ib99c815cfc8823e22fc1d76e201903c34ed0f61b

Related: rhbz#1367846 queue and merge scroll events

Reviewed-on: https://gerrit.libreoffice.org/37779
Reviewed-by: Caolán McNamara 
Tested-by: Caolán McNamara 
(cherry picked from commit 7f60978b2ccd0e17816b78bde60c6e0e60a9d52e)

Change-Id: Ib45f61bbb35bd240829491ac8a79803222974778
Reviewed-on: https://gerrit.libreoffice.org/37913
Tested-by: Jenkins 
Reviewed-by: Miklos Vajna 

diff --git a/include/vcl/commandevent.hxx b/include/vcl/commandevent.hxx
index 5b9cc09a7eaa..371fd54716d9 100644
--- a/include/vcl/commandevent.hxx
+++ b/include/vcl/commandevent.hxx
@@ -140,7 +140,7 @@ class VCL_DLLPUBLIC CommandWheelData
 private:
 long  mnDelta;
 long  mnNotchDelta;
-sal_uLong mnLines;
+doublemnLines;
 CommandWheelMode  mnWheelMode;
 sal_uInt16mnCode;
 bool  mbHorz;
@@ -149,13 +149,13 @@ private:
 public:
 CommandWheelData();
 CommandWheelData( long nWheelDelta, long nWheelNotchDelta,
-  sal_uLong nScrollLines,
+  double nScrollLines,
   CommandWheelMode nWheelMode, sal_uInt16 
nKeyModifier,
   bool bHorz, bool bDeltaIsPixel = false );
 
 longGetDelta() const { return mnDelta; }
 longGetNotchDelta() const { return mnNotchDelta; }
-sal_uLong   GetScrollLines() const { return mnLines; }
+double  GetScrollLines() const { return mnLines; }
 boolIsHorz() const { return mbHorz; }
 boolIsDeltaPixel() const { return mbDeltaIsPixel; }
 
diff --git a/include/vcl/window.hxx b/include/vcl/window.hxx
index 4fdb80560d68..7d6f69ce9b28 100644
--- a/include/vcl/window.hxx
+++ b/include/vcl/window.hxx
@@ -719,7 +719,7 @@ private:
 SAL_DLLPRIVATE void 
ImplCallActivateListeners(vcl::Window*);
 SAL_DLLPRIVATE void 
ImplCallDeactivateListeners(vcl::Window*);
 
-SAL_DLLPRIVATE static void  ImplHandleScroll( ScrollBar* pHScrl, 
long nX, ScrollBar* pVScrl, long nY );
+SAL_DLLPRIVATE static void  ImplHandleScroll(ScrollBar* pHScrl, 
double nX, ScrollBar* pVScrl, double nY);
 
 SAL_DLLPRIVATE Rectangle
ImplOutputToUnmirroredAbsoluteScreenPixel( const Rectangle& rRect ) const;
 SAL_DLLPRIVATE long ImplGetUnmirroredOutOffX();
diff --git a/vcl/inc/salwtype.hxx b/vcl/inc/salwtype.hxx
index b7f803eee86e..c25ca80909dc 100644
--- a/vcl/inc/salwtype.hxx
+++ b/vcl/inc/salwtype.hxx
@@ -149,7 +149,7 @@ struct SalWheelMouseEvent
 longmnY;// Y-Position (Pixel, TopLeft-Output)
 longmnDelta;// Number of rotations
 longmnNotchDelta;   // Number of fixed rotations
-sal_uLong   mnScrollLines;  // Actual number of lines to scroll
+double  mnScrollLines;  // Actual number of lines to scroll
 sal_uInt16  mnCode; // SV-Modifiercode 
(KEY_SHIFT|KEY_MOD1|KEY_MOD2|MOUSE_LEFT|MOUSE_MIDDLE|MOUSE_RIGHT)
 boolmbHorz; // Horizontal
 boolmbDeltaIsPixel; // delta value is a pixel value (on touch 
devices)
diff --git a/vcl/inc/unx/gtk/gtkframe.hxx b/vcl/inc/unx/gtk/gtkframe.hxx
index 3deb4c4a8c28..fcb4498512d9 100644
--- a/vcl/inc/unx/gtk/gtkframe.hxx
+++ b/vcl/inc/unx/gtk/gtkframe.hxx
@@ -30,6 +30,7 @@
 #include 
 
 #include 
+#include 
 #include 
 #include 
 #include 
@@ -281,7 +282,7 @@ class GtkSalFrame : public SalFrame
 static gboolean signalKey( GtkWidget*, GdkEventKey*, gpointer );
 static gboolean signalDelete( GtkWidget*, GdkEvent*, gpointer );
 static gboolean signalWindowState( GtkWidget*, GdkEvent*, gpointer );
-static gboolean signalScroll( GtkWidget*, GdkEventScroll*, gpointer );
+static gboolean signalScroll( GtkWidget*, GdkEvent*, gpointer );
 static gboolean signalCrossing( GtkWidget*, GdkEventCrossing*, 
gpointer );
 static gboolean signalVisibility( GtkWidget*

[Libreoffice-commits] core.git: Branch 'libreoffice-5-3' - extensions/source svx/source

2017-05-24 Thread Caolán McNamara
 extensions/source/propctrlr/standardcontrol.cxx |   36 +---
 svx/source/tbxctrls/tbcontrl.cxx|9 ++
 2 files changed, 17 insertions(+), 28 deletions(-)

New commits:
commit c05f35f4f56a1e65b92f4b1bc43b0fa6138d209c
Author: Caolán McNamara 
Date:   Mon May 22 12:05:17 2017 +0100

Resolves: tdf#107981 SID_FM_CTL_PROPERTIES colorbox needs a 'default' entry

we don't need MakeHexStr either, the colorbox will do that on its own

Reviewed-on: https://gerrit.libreoffice.org/37898
Reviewed-by: Caolán McNamara 
Tested-by: Caolán McNamara 
(cherry picked from commit 7539c77fd49889015ad3a952009e33fac5324df6)

Change-Id: Ifad523092c0f15cd51d0d829790c0cec1c96bb53
Reviewed-on: https://gerrit.libreoffice.org/37905
Tested-by: Jenkins 
Reviewed-by: Miklos Vajna 

diff --git a/extensions/source/propctrlr/standardcontrol.cxx 
b/extensions/source/propctrlr/standardcontrol.cxx
index af15abfb508e..b99445c6e315 100644
--- a/extensions/source/propctrlr/standardcontrol.cxx
+++ b/extensions/source/propctrlr/standardcontrol.cxx
@@ -642,47 +642,27 @@ namespace pcr
 
 #define LB_DEFAULT_COUNT 20
 
-OUString MakeHexStr(sal_uInt32 nVal, sal_Int32 nLength)
-{
-OUStringBuffer aStr;
-while (nVal>0)
-{
-char c = char(nVal & 0x000F);
-nVal >>= 4;
-if (c<=9) c += '0';
-else c += 'A' - 10;
-aStr.insert(0, c);
-}
-while (aStr.getLength() < nLength) aStr.insert(0, '0');
-return aStr.makeStringAndClear();
-}
-
 OColorControl::OColorControl(vcl::Window* pParent, WinBits nWinStyle)
 : OColorControl_Base(PropertyControlType::ColorListBox, pParent, 
nWinStyle)
 {
+getTypedControlWindow()->SetSlotId(SID_FM_CTL_PROPERTIES);
 }
 
 void SAL_CALL OColorControl::setValue( const Any& _rValue ) throw 
(IllegalTypeException, RuntimeException, std::exception)
 {
-if ( _rValue.hasValue() )
-{
-css::util::Color nColor = COL_TRANSPARENT;
+css::util::Color nColor = COL_TRANSPARENT;
+if (_rValue.hasValue())
 _rValue >>= nColor;
-::Color aRgbCol((ColorData)nColor);
-   getTypedControlWindow()->SelectEntry(std::make_pair(aRgbCol, 
MakeHexStr(nColor, 8)));
-}
-else
-getTypedControlWindow()->SetNoSelection();
+getTypedControlWindow()->SelectEntry(::Color((ColorData)nColor));
 }
 
 Any SAL_CALL OColorControl::getValue() throw (RuntimeException, 
std::exception)
 {
 Any aPropValue;
-if (!getTypedControlWindow()->IsNoSelection())
-{
-::Color aRgbCol = getTypedControlWindow()->GetSelectEntryColor();
-aPropValue <<= (css::util::Color)aRgbCol.GetColor();
-}
+::Color aRgbCol = getTypedControlWindow()->GetSelectEntryColor();
+if (aRgbCol == COL_TRANSPARENT)
+return aPropValue;
+aPropValue <<= (css::util::Color)aRgbCol.GetColor();
 return aPropValue;
 }
 
diff --git a/svx/source/tbxctrls/tbcontrl.cxx b/svx/source/tbxctrls/tbcontrl.cxx
index 95ec9f400143..7b5a6cfd7843 100644
--- a/svx/source/tbxctrls/tbcontrl.cxx
+++ b/svx/source/tbxctrls/tbcontrl.cxx
@@ -1300,6 +1300,11 @@ SvxColorWindow::SvxColorWindow(const OUString&   
 rCommand,
 mpButtonAutoColor->SetText( SVX_RESSTR( RID_SVXSTR_AUTOMATIC ) );
 break;
 }
+case SID_FM_CTL_PROPERTIES:
+{
+mpButtonAutoColor->SetText( SVX_RESSTR( RID_SVXSTR_AUTOMATIC ) );
+break;
+}
 default:
 {
 mpButtonAutoColor->Hide();
@@ -1499,6 +1504,10 @@ namespace
 aColor = COL_TRANSPARENT;
 sColorName = SVX_RESSTR(RID_SVXSTR_TRANSPARENT);
 break;
+case SID_FM_CTL_PROPERTIES:
+aColor = COL_TRANSPARENT;
+sColorName = SVX_RESSTR(RID_SVXSTR_AUTOMATIC);
+break;
 case SID_ATTR_CHAR_COLOR:
 case SID_ATTR_CHAR_COLOR2:
 case SID_EXTRUSION_3D_COLOR:
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: vcl/source

2017-05-24 Thread Miklos Vajna
 vcl/source/filter/graphicfilter.cxx |  119 ++--
 1 file changed, 73 insertions(+), 46 deletions(-)

New commits:
commit e5b8b58ab02ca6f19b2a12d80c41d667ec416f1f
Author: Miklos Vajna 
Date:   Wed May 24 07:43:40 2017 +0200

vcl: factor out graphic import filter state to GraphicImportContext

Have all the data needed to read pixel data at one place.

Change-Id: Ie00b154b941c775d6ff4bf11019464423b3e2425
Reviewed-on: https://gerrit.libreoffice.org/37975
Reviewed-by: Miklos Vajna 
Tested-by: Jenkins 

diff --git a/vcl/source/filter/graphicfilter.cxx 
b/vcl/source/filter/graphicfilter.cxx
index 01807dc71ac8..c5bab5cd8891 100644
--- a/vcl/source/filter/graphicfilter.cxx
+++ b/vcl/source/filter/graphicfilter.cxx
@@ -1316,87 +1316,114 @@ sal_uInt16 GraphicFilter::ImportGraphic( Graphic& 
rGraphic, const OUString& rPat
 return ImportGraphic( rGraphic, rPath, rIStream, nFormat, 
pDeterminedFormat, nImportFlags, nullptr, pExtHeader );
 }
 
+/// Contains a stream and other associated data to import pixels into a
+/// Graphic.
+struct GraphicImportContext
+{
+/// Pixel data is read from this stream.
+std::shared_ptr m_pStream;
+/// The Graphic the import filter gets.
+std::shared_ptr m_pGraphic;
+/// Write pixel data using this access.
+std::unique_ptr m_pAccess;
+/// Signals if import finished correctly.
+sal_uInt16 m_nStatus = GRFILTER_FILTERERROR;
+/// Original graphic format.
+GfxLinkType m_eLinkType = GfxLinkType::NONE;
+/// Position of the stream before reading the data.
+sal_uInt64 m_nStreamBegin = 0;
+/// Flags for the import filter.
+GraphicFilterImportFlags m_nImportFlags = GraphicFilterImportFlags::NONE;
+};
+
 void GraphicFilter::ImportGraphics(std::vector< std::shared_ptr >& 
rGraphics, const std::vector< std::shared_ptr >& rStreams)
 {
+std::vector aContexts;
+aContexts.reserve(rStreams.size());
 for (const auto& pStream : rStreams)
 {
-Graphic* pGraphic = nullptr;
+aContexts.push_back(GraphicImportContext());
+GraphicImportContext& rContext = aContexts.back();
 
 if (pStream)
 {
-auto pG = o3tl::make_unique();
-sal_uInt16 nStatus = GRFILTER_OK;
+rContext.m_pStream = pStream;
+rContext.m_pGraphic = std::make_shared();
+rContext.m_nStatus = GRFILTER_OK;
 
 // Detect the format.
 ResetLastError();
-sal_uLong nStreamBegin = pStream->Tell();
+rContext.m_nStreamBegin = pStream->Tell();
 sal_uInt16 nFormat = GRFILTER_FORMAT_DONTKNOW;
-nStatus = ImpTestOrFindFormat(OUString(), *pStream, nFormat);
-pStream->Seek(nStreamBegin);
+rContext.m_nStatus = ImpTestOrFindFormat(OUString(), *pStream, 
nFormat);
+pStream->Seek(rContext.m_nStreamBegin);
 
 // Import the graphic.
-if (nStatus == GRFILTER_OK && !pStream->GetError())
+if (rContext.m_nStatus == GRFILTER_OK && !pStream->GetError())
 {
 OUString aFilterName = pConfig->GetImportFilterName(nFormat);
-GfxLinkType eLinkType = GfxLinkType::NONE;
 
 if (aFilterName.equalsIgnoreAsciiCase(IMP_JPEG))
 {
-GraphicFilterImportFlags nImportFlags = 
GraphicFilterImportFlags::SetLogsizeForJpeg;
+rContext.m_nImportFlags = 
GraphicFilterImportFlags::SetLogsizeForJpeg;
 
-sal_uInt64 nPosition = pStream->Tell();
-if (!ImportJPEG( *pStream, *pG, nImportFlags | 
GraphicFilterImportFlags::OnlyCreateBitmap, nullptr))
-nStatus = GRFILTER_FILTERERROR;
+if (!ImportJPEG( *pStream, *rContext.m_pGraphic, 
rContext.m_nImportFlags | GraphicFilterImportFlags::OnlyCreateBitmap, nullptr))
+rContext.m_nStatus = GRFILTER_FILTERERROR;
 else
 {
-Bitmap& rBitmap = 
const_cast(pG->GetBitmapExRef().GetBitmapRef());
-Bitmap::ScopedWriteAccess pWriteAccess(rBitmap);
-pStream->Seek(nPosition);
-if (!ImportJPEG(*pStream, *pG, nImportFlags | 
GraphicFilterImportFlags::UseExistingBitmap, &pWriteAccess))
-nStatus = GRFILTER_FILTERERROR;
+Bitmap& rBitmap = 
const_cast(rContext.m_pGraphic->GetBitmapExRef().GetBitmapRef());
+rContext.m_pAccess = 
o3tl::make_unique(rBitmap);
+pStream->Seek(rContext.m_nStreamBegin);
+if (!ImportJPEG(*pStream, *rContext.m_pGraphic, 
rContext.m_nImportFlags | GraphicFilterImportFlags::UseExistingBitmap, 
rContext.m_pAccess.get()))
+rContext.m_nStatus = GRFILTER_FILTERERROR;
 else
-  

[Libreoffice-commits] help.git: source/text

2017-05-24 Thread Gabor Kelemen
 source/text/shared/00/0200.xhp |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 9c0f31652cb806846bad8f814006209489c58b6b
Author: Gabor Kelemen 
Date:   Tue May 23 23:55:59 2017 +0200

PlaceWare filter was dropped so don't mention its format

Change-Id: Ifdfc7ca4de9565f69d8e14b91e219044e5ebd7f8
Reviewed-on: https://gerrit.libreoffice.org/37968
Reviewed-by: Gabor Kelemen 
Tested-by: Gabor Kelemen 

diff --git a/source/text/shared/00/0200.xhp 
b/source/text/shared/00/0200.xhp
index 0bd8b9f37..77301893e 100644
--- a/source/text/shared/00/0200.xhp
+++ b/source/text/shared/00/0200.xhp
@@ -33,7 +33,7 @@
   
 
 When you export 
graphical elements to a file, you can select the file type. For most supported 
file types a dialog opens where you can setup export options.
-The following file 
types do not show an options dialog: PWP, RAS, SVG, TIFF, XPM.
+The following file 
types do not show an options dialog: RAS, SVG, TIFF, XPM.
 The other file types 
show options dialogs where you can set the width and height of the exported 
image.
 Depending on the 
file type, you can specify some more options. Press Shift+F1 and hover over the 
control to see an extended help text.
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: helpcontent2

2017-05-24 Thread Gabor Kelemen
 helpcontent2 |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 7299b7301cbb6013ba4ec36753a58d772b64a007
Author: Gabor Kelemen 
Date:   Tue May 23 23:55:59 2017 +0200

Updated core
Project: help  9c0f31652cb806846bad8f814006209489c58b6b

PlaceWare filter was dropped so don't mention its format

Change-Id: Ifdfc7ca4de9565f69d8e14b91e219044e5ebd7f8
Reviewed-on: https://gerrit.libreoffice.org/37968
Reviewed-by: Gabor Kelemen 
Tested-by: Gabor Kelemen 

diff --git a/helpcontent2 b/helpcontent2
index 23e991de25bb..9c0f31652cb8 16
--- a/helpcontent2
+++ b/helpcontent2
@@ -1 +1 @@
-Subproject commit 23e991de25bb224fc7c6561b9cb34632fecd7220
+Subproject commit 9c0f31652cb806846bad8f814006209489c58b6b
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits
diff --git a/loleaflet/src/control/Control.Menubar.js 
b/loleaflet/src/control/Control.Menubar.js
index 8206ab5c..33d2e1e1 100644
--- a/loleaflet/src/control/Control.Menubar.js
+++ b/loleaflet/src/control/Control.Menubar.js
@@ -2,7 +2,7 @@
 * Control.Menubar
 */
 
 /* global $ _ map title vex revHistoryEnabled closebutton */
 L.Control.Menubar = L.Control.extend({
// TODO: Some mechanism to stop the need to copy duplicate menus (eg. 
Help)
options: {
@@ -541,6 +541,10 @@ L.Control.Menubar = L.Control.extend({
_createMenu: function(menu) {
var itemList = [];
for (var i in menu) {
+   if (menu[i].id === 'help' && disableAbout) {
+   menu[i].menu.pop();
+   }
+
if (map._permission === 'readonly' && menu[i].type === 
'menu') {
var found = false;
for (var j in 
this.options.allowedReadonlyMenus) {
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: desktop/inc desktop/Library_deploymentgui.mk desktop/source officecfg/registry

2017-05-24 Thread Muhammet Kara
 desktop/Library_deploymentgui.mk |2 
 desktop/inc/dp_gui.hrc   |1 
 desktop/source/deployment/gui/dp_gui_dialog.src  |6 ++
 desktop/source/deployment/gui/dp_gui_dialog2.cxx |   30 
+-
 officecfg/registry/schema/org/openoffice/Office/ExtensionManager.xcs |   12 

 5 files changed, 50 insertions(+), 1 deletion(-)
@@ -2,7 +2,7 @@
 */
 
-/* global $ _ map title vex revHistoryEnabled closebutton */
+/* global $ _ map title vex revHistoryEnabled closebutton disableAbout*/
 L.Control.Menubar = L.Control.extend({
// TODO: Some mechanism to stop the need to copy duplicate menus (eg. 

New commits:
commit 99b7c4f57d7fe3cac772cce38e2dd6879e128315
Author: Muhammet Kara 
Date:   Mon May 22 11:41:20 2017 +0300

tdf#36019: Dynamically enable/disable extension installation via GUI

Now extension installation via the Extension Manager dialog can be
dynamically enabled/disabled from the expert configurations.

This also affects the installation by double-clicking the extension
file in the file manager, but doesn't affect the unopkg commands.

Change-Id: I70c2c83c2458115b366c7fdcc06f72e11df4726b
Reviewed-on: https://gerrit.libreoffice.org/36688
Tested-by: Jenkins 
Reviewed-by: Muhammet Kara 
